/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.accservice.core;

import org.eclipse.actf.model.InvalidComponentException;

/**
 * Interface for exposing accessibility-related properties of text components to the validation engine.
 *
 * @see IAccessibleElement2
 * @author Mike Smith
 */
public interface IAccessibleTextElement
{

	/**
	 * get the text for the accessible text object
	 * 
	 * @return text or an empty string if no text is provided
	 * @throws InvalidComponentException
	 */
	public String getText () throws InvalidComponentException;

	/**
	 * get the offset of the caret for the accessible text object
	 * 
	 * @return caret offset
	 * @throws InvalidComponentException
	 */
	public long getCaretOffset () throws InvalidComponentException;

	/**
	 * get the attributes at the specified offset of the text
	 * 
	 * @param offset zero index of caret offset
	 * @return attributes or an empty string if no description is provided
	 * @throws InvalidComponentException
	 */
	public Object getAttributes (long offset) throws InvalidComponentException;

	/**
	 * get number of active non-contiguous selections 
	 * 
	 * @return the number of selections
	 * @throws InvalidComponentException
	 */
	public long getSelectionCount () throws InvalidComponentException;

	/**
	 * get the text of the selected object
	 * 
	 * @param index zero index of selected text objects
	 * @return the number of selections or empty string if index is out of range
	 * @throws InvalidComponentException
	 */
	public String getSelectedText (long index) throws InvalidComponentException;

	/**
	 * get the starting index of the selected text
	 * 
	 * @param index zero index of selected text objects
	 * @return the starting index of the selection
	 * @throws InvalidComponentException
	 */
	public long getSelectedTextStart (long index)
		throws InvalidComponentException;

	/**
	 * get the ending index of the selected text
	 * 
	 * @param index zero index of selected text objects 
	 * @return the ending index of the selection
	 * @throws InvalidComponentException
	 */
	public long getSelectedTextEnd (long index)
		throws InvalidComponentException;
}
