/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* IBM Corporation - initial API and implementation
*******************************************************************************/ 


package org.eclipse.actf.accservice.core;

import org.eclipse.actf.model.InvalidComponentException;

/**
 * represents the value of a control and the upper and lower bounds of the control.
 * Note that the type of the value is implementation-dependent. Not all controls have values.
 *  
 * @author <a href="mailto:masquill@us.ibm.com>Mike Squillace</a>
 *
 */
public interface IAccessibleValueElement
{

	/**
	 * get the current value
	 * 
	 * @return current value of the control or <code>null</code> if value is not supported
	 * @throws InvalidComponentException 
	 */
	public Object getCurrentValue () throws InvalidComponentException;
	
	/**
	 * set the current value of the control
	 * 
	 * @param value - new value
	 * @throws InvalidComponentException 
	 */
	public void setCurrentValue (Object value) throws InvalidComponentException;
	
	/**
	 * gets the minimum value supported by the control
	 * 
	 * @return minimum value supported
	 * @throws InvalidComponentException 
	 */
	public Object getMinimumValue () throws InvalidComponentException;
	
	/**
	 * gets the maximum value supported by the control
	 * 
	 * @return maximum value supported
	 * @throws InvalidComponentException 
	 */
	public Object getMaximumValue () throws InvalidComponentException;
	
}
