/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.accservice.core.win32.ia2;

import org.eclipse.actf.accservice.AccessibilityServiceException;
import org.eclipse.actf.accservice.AccessibilityServiceManager;
import org.eclipse.actf.accservice.IWindowService;
import org.eclipse.actf.accservice.core.IAccessibleElement;
import org.eclipse.actf.accservice.core.win32.msaa.Msaa;
import org.eclipse.actf.accservice.core.win32.msaa.MsaaAccessibilityEventService;
import org.eclipse.actf.accservice.core.win32.msaa.MsaaAccessible;
import org.eclipse.actf.accservice.event.AccessibilityModelEvent;
import org.eclipse.actf.model.events.ModelEventType;


public class IA2AccessibilityEventService extends MsaaAccessibilityEventService
{	
	private static final long serialVersionUID = 4370682108473838982L;
	public static final int IA2_EVENT_ACTION_CHANGED	= 0x101;
	public static final int IA2_EVENT_ACTIVE_DECENDENT_CHANGED	= IA2_EVENT_ACTION_CHANGED + 1;
	public static final int IA2_EVENT_ACTIVE_DESCENDENT_CHANGED = IA2_EVENT_ACTIVE_DECENDENT_CHANGED;
	public static final int IA2_EVENT_DOCUMENT_ATTRIBUTE_CHANGED	= IA2_EVENT_ACTIVE_DECENDENT_CHANGED + 1;
	public static final int IA2_EVENT_DOCUMENT_CONTENT_CHANGED	= IA2_EVENT_DOCUMENT_ATTRIBUTE_CHANGED + 1;
	public static final int IA2_EVENT_DOCUMENT_LOAD_COMPLETE	= IA2_EVENT_DOCUMENT_CONTENT_CHANGED + 1;
	public static final int IA2_EVENT_DOCUMENT_LOAD_STOPPED	= IA2_EVENT_DOCUMENT_LOAD_COMPLETE + 1;
	public static final int IA2_EVENT_DOCUMENT_RELOAD	= IA2_EVENT_DOCUMENT_LOAD_STOPPED + 1;
	public static final int IA2_EVENT_HYPERLINK_END_INDEX_CHANGED	= IA2_EVENT_DOCUMENT_RELOAD + 1;
	public static final int IA2_EVENT_HYPERLINK_NUMBER_OF_ANCHORS_CHANGED	= IA2_EVENT_HYPERLINK_END_INDEX_CHANGED + 1;
	public static final int IA2_EVENT_HYPERLINK_SELECTED_LINK_CHANGED	= IA2_EVENT_HYPERLINK_NUMBER_OF_ANCHORS_CHANGED + 1;
	public static final int IA2_EVENT_HYPERTEXT_LINK_ACTIVATED	= IA2_EVENT_HYPERLINK_SELECTED_LINK_CHANGED + 1;
	public static final int IA2_EVENT_HYPERTEXT_LINK_SELECTED	= IA2_EVENT_HYPERTEXT_LINK_ACTIVATED + 1;
	public static final int IA2_EVENT_HYPERLINK_START_INDEX_CHANGED	= IA2_EVENT_HYPERTEXT_LINK_SELECTED + 1;
	public static final int IA2_EVENT_HYPERTEXT_CHANGED	= IA2_EVENT_HYPERLINK_START_INDEX_CHANGED + 1;
	public static final int IA2_EVENT_HYPERTEXT_NLINKS_CHANGED	= IA2_EVENT_HYPERTEXT_CHANGED + 1;
	public static final int IA2_EVENT_OBJECT_ATTRIBUTE_CHANGED	= IA2_EVENT_HYPERTEXT_NLINKS_CHANGED + 1;
	public static final int IA2_EVENT_PAGE_CHANGED	= IA2_EVENT_OBJECT_ATTRIBUTE_CHANGED + 1;
	public static final int IA2_EVENT_ROLE_CHANGED	= IA2_EVENT_PAGE_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_CAPTION_CHANGED	= IA2_EVENT_ROLE_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_COLUMN_DESCRIPTION_CHANGED	= IA2_EVENT_TABLE_CAPTION_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_COLUMN_HEADER_CHANGED	= IA2_EVENT_TABLE_COLUMN_DESCRIPTION_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_MODEL_CHANGED	= IA2_EVENT_TABLE_COLUMN_HEADER_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_ROW_DESCRIPTION_CHANGED	= IA2_EVENT_TABLE_MODEL_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_ROW_HEADER_CHANGED	= IA2_EVENT_TABLE_ROW_DESCRIPTION_CHANGED + 1;
	public static final int IA2_EVENT_TABLE_SUMMARY_CHANGED	= IA2_EVENT_TABLE_ROW_HEADER_CHANGED + 1;
	public static final int IA2_EVENT_TEXT_ATTRIBUTE_CHANGED	= IA2_EVENT_TABLE_SUMMARY_CHANGED + 1;
	public static final int IA2_EVENT_TEXT_CARET_MOVED	= IA2_EVENT_TEXT_ATTRIBUTE_CHANGED + 1;
	public static final int IA2_EVENT_TEXT_CHANGED	= IA2_EVENT_TEXT_CARET_MOVED + 1;
	public static final int IA2_EVENT_TEXT_COLUMN_CHANGED	= IA2_EVENT_TEXT_CHANGED + 1;
	public static final int IA2_EVENT_TEXT_INSERTED	= IA2_EVENT_TEXT_COLUMN_CHANGED + 1;
	public static final int IA2_EVENT_TEXT_REMOVED	= IA2_EVENT_TEXT_INSERTED + 1;
	public static final int IA2_EVENT_TEXT_UPDATED	= IA2_EVENT_TEXT_REMOVED + 1;
	public static final int IA2_EVENT_TEXT_SELECTION_CHANGED	= IA2_EVENT_TEXT_UPDATED + 1;
	public static final int IA2_EVENT_VISIBLE_DATA_CHANGED	= IA2_EVENT_TEXT_SELECTION_CHANGED + 1;

	public IA2AccessibilityEventService (IWindowService windowService) {
		super(windowService);
	}
	
	/**
	 * callback from the native Windows system for out-of-process IA2 events. The parameters are:
	 * 
	 * <p><ul>
	 * <li>event information (hwnd, child Id, Object ID, event ID)to form a new <code>IA2Accessible</code>. 
	 * In this case, the source of the resulting event will be this <code>IA2Accessible</code> object.
	 * </ul></p>
	 * 
	 * <p>The appropriate listeners for the given event id are notified and the <code>AccesibilityModelEvent</code> is 
	 * created from the formed <code>IA2Accessible</code> </p>
	 * 
	 * @param eventId
	 * @param hwnd
	 * @param idObject
	 * @param idChild
	 * @param time
	 */
	protected static void winEventCallback(int eventId, int hwnd, 
			int idObject, int idChild,long time, int isGlobal) {
		if(initClockTicks > time){
			setTimeDiff();
		}
		long dms =System.currentTimeMillis();
		long ctime = time+ timeDiff;
		AccessibilityModelEvent accEvent = null;	
		IAccessibleElement acc = null;
		int ref = createAccessibleObjectFromEvent(hwnd,idObject,idChild);
		if (ref!=0) {
			acc = new IA2Accessible(ref);
		} else {
			ref = MsaaAccessibilityEventService.createAccessibleObjectFromEvent(hwnd,idObject,idChild);
			if (ref!=0) {
				acc = new MsaaAccessible(ref);
			}
		}
		
		if (acc != null) {
			accEvent = new AccessibilityModelEvent(acc);
			accEvent.setEventType(eventName(eventId));
			accEvent.setTimeMillis(ctime);
			try {
				IWindowService winService = AccessibilityServiceManager.getInstance()
					.getAccessibilityService(IA2AccessibilityService.IA2_ACCSERVICE_NAME).getWindowService();
				int pid;
				if(isGlobal==0){
				 pid = hwnd!=0 ? winService.getProcessId(hwnd): winService.getProcessId(winService.getActiveWindow());
				}else{
					pid =0;
				}
				fireAccessibilityModelEvent(accEvent, eventId, pid , false);
			} catch (AccessibilityServiceException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}
	protected static native int createAccessibleObjectFromEvent(int hwnd, int idObject, int idChild);

	public static String eventName(int event){
		String evName = null;
		IA2GuiModel iarch = new IA2GuiModel();
		ModelEventType itype= iarch.getModelEventType(Integer.valueOf(event));
		if(itype!=null){
			evName = itype.getEventName();
		}
		return evName;
	}
	
	/**
	 * callback from the native Windows system for in-process IA2 events. 
	 * The event information is read from a memory map file as a string array.
	 *  
	 * <p>The appropriate listeners for the given event id are notified and the <code>AccesibilityModelEvent</code> is  
	 * created. Here, the source of the AccesibilityModelEvent is a string array containing information about the 
	 * accessible that fired the event</p>
	 */
	protected void winEventIPCallback () {
		int mPtr = openFileMapping(FILE_MAP_READ|FILE_MAP_WRITE, false,
				fileMappingObjName);
		int state =0;
		int eventId =0;
		long timeMillis =0;
		String[] source=null;
		if(mPtr != 0) {
			int vPtr = mapViewOfFile(mPtr,
					FILE_MAP_READ|FILE_MAP_WRITE, 0, 0, 0);
			if(vPtr != 0) {
				String props[] = readFromMem(vPtr);
				if(props!=null && props.length==5){
					String roleName =null;
					try {
						long role = Long.parseLong(props[1]);
						roleName= Msaa.getMsaaActfRoleName(role);
						if(roleName==null){
							roleName= IA2.getIA2ActfRoleName(role);
						}
					} catch (NumberFormatException e) {
						// role returned as a string
						roleName= props[1];
					}
					state= Integer.parseInt(props[2]);
					eventId = Integer.parseInt(props[3]);
					timeMillis = Long.parseLong(props[4]);
					if(initClockTicks > timeMillis){
							setTimeDiff();
					}
					timeMillis = timeMillis+timeDiff;
					
					source = new String[5];
					source[0]=props[0];
					source[1]=  roleName;
					source[2]= Msaa.getState(state).toString();
					source[3]= eventName(eventId);
					source[4]= Long.valueOf(timeMillis).toString();
				}
				unmapViewOfFile(vPtr);
			}
			closeHandle(mPtr);
		}
		//handle data
		AccessibilityModelEvent accEvent = null;
		if (source!=null){
			try {
				accEvent = new AccessibilityModelEvent(source);		
				fireAccessibilityModelEvent(accEvent, eventId, windowService.getProcessId(windowService.getActiveWindow()), true);
			} catch (RuntimeException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
	}

	//protected native int internalSetWinEventHook (int eventMin, int eventMax, int idThread, int idProcess, int  dwFlags);
	//public native boolean initThread();
}
