/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.accservice.core.win32.ia2;

import java.awt.Point;

import org.eclipse.actf.accservice.AccessibilityServiceException;
import org.eclipse.actf.accservice.IAccessibilityEventService;
import org.eclipse.actf.accservice.IWindowService;
import org.eclipse.actf.accservice.core.IAccessibleElement;
import org.eclipse.actf.accservice.core.win32.msaa.MsaaAccessibilityService;
import org.eclipse.actf.model.InvalidComponentException;
import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;


public class IA2AccessibilityService extends MsaaAccessibilityService
{


	private static final long serialVersionUID = -3956586839108596041L;

	/**
	 * name of dynamic module for IA2 access; value is 'actf-ia2'
	 */
	public static final String ACTF_IA2_LIBRARY_NAME = "actf-ia2";
	
	/**
	 * accessibility service name for this service; value is 'ia2'
	 */
	public static final String IA2_ACCSERVICE_NAME = "ia2";
	
	private IWindowService _windowService = new IA2WindowService();
	private IAccessibilityEventService _accEventService = new IA2AccessibilityEventService(_windowService);
	
	/** {@inheritDoc} */
	public IAccessibleElement createAccessibleElement(Object obj, Object[] params)
			throws InvalidComponentException {
		IA2AccessibilityService.internalCoInitialize();
		IA2Accessible ia2Acc = null;
		if (obj instanceof Point) {
			ia2Acc = new IA2Accessible((Point) obj);
		} else if (obj instanceof Integer) {
			int hwnd = ((Integer) obj).intValue();
			int childId = -1;
			if( params !=null){
				int length = params.length;

				if (length > 0 && (params[0] instanceof Integer)) {
					childId = ((Integer) params[0]).intValue();
				}
			}
			ia2Acc = new IA2Accessible(hwnd, childId);
		}

		return ia2Acc;
	}

	/** {@inheritDoc} */
	public IAccessibilityEventService getAccessibilityEventService() {
		return _accEventService;
	}

	/** {@inheritDoc} */
	public IWindowService getWindowService() {
		return _windowService;
	}

	public void initialize() throws AccessibilityServiceException {
		super.initialize();
		try {
			System.loadLibrary(ACTF_IA2_LIBRARY_NAME);
			}catch (Throwable e) {
			LoggingUtil.println(IReporter.SYSTEM_NONFATAL, "unable to load library " + ACTF_IA2_LIBRARY_NAME, e);
		}
	}
	protected static native boolean internalCoInitialize();
	protected static native boolean internalCoUnInitialize();

}
