/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* IBM Corporation - initial API and implementation
*******************************************************************************/ 
/**
 * 
 */
package org.eclipse.actf.accservice.javapp;


import org.eclipse.actf.accservice.AccessibilityServiceException;
import org.eclipse.actf.accservice.IAccessibilityEventService;
import org.eclipse.actf.accservice.IAccessibilityService;
import org.eclipse.actf.accservice.IWindowService;
import org.eclipse.actf.accservice.core.IAccessibleElement;
import org.eclipse.actf.model.InvalidComponentException;
import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;


/**
 * @author wscarter
 *
 */
public class JavaAccessibilityService implements IAccessibilityService
{
	
	/**
	 * accessibility service name for this service; value is 'jaapi'
	 */
	public static final String JAVA_ACCSERVICE_NAME = "jaapi";

	private IWindowService _windowService;
	private IAccessibilityEventService _accEventService;
	
	public IAccessibleElement createAccessibleElement(Object obj, Object[] params)
	throws InvalidComponentException {
		return new JavaAccessible(obj);
	}
	
	public IAccessibilityEventService getAccessibilityEventService() {
		return _accEventService;
	}

	public IWindowService getWindowService() {
		return _windowService;
	}
	
	public void initialize() throws AccessibilityServiceException {
		// insure that the accessibility classes are available
		try {
			Class cls = Class.forName("com.sun.java.accessibility.util.EventQueueMonitor");
			_windowService = new JavaWindowService();
			_accEventService = new JavaAccessibilityEventService(_windowService);
		} catch (ClassNotFoundException cnfe) {
			LoggingUtil.println(IReporter.SYSTEM_NONFATAL,"package com.sun.java.accessibility.util not found");
		}
	}
}
