/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.accservice.javapp;

import javax.accessibility.AccessibleEditableText;
import javax.swing.text.SimpleAttributeSet;

import org.eclipse.actf.accservice.core.IAccessibleEditableTextElement;
import org.eclipse.actf.model.InvalidComponentException;

/**
 * implementation of the <code>IAccessibleEditableTextElement</code> object for the Java Accesibility API's <code>AccessibleIcon</code>.
 * 
 * @see javax.accessibility.AccessibleIcon
 * @author Kavitha Teegala
 */
public class JavaAccessibleEditableText implements IAccessibleEditableTextElement
{

	private AccessibleEditableText _eText;

	/**
	 * Constructor used to create an accessible image object. This constructor will usually 
	 * be invoked from <code>JavaAccessible</code> and is not typically called by clients.
	 * 
	 * @param text 
	 */
	public JavaAccessibleEditableText (AccessibleEditableText text) {
		_eText = text;
	}

	private void checkIsValid () throws InvalidComponentException {
		if (_eText == null) { throw new InvalidComponentException("No accessible context"); }
	}

	public void copyText(int startIndex, int endIndex) throws InvalidComponentException {
		checkIsValid();
		 _eText.getTextRange(startIndex, endIndex);
	}

	public void cutText(int startIndex, int endIndex) throws InvalidComponentException {
		checkIsValid();	
		_eText.cut(startIndex, endIndex);
		
	}

	public void deleteText(int startIndex, int endIndex) throws InvalidComponentException {
		checkIsValid();
		_eText.delete(startIndex, endIndex);
		
	}

	public void insertText(int index, String s) throws InvalidComponentException {
		checkIsValid();
		_eText.insertTextAtIndex(index, s);		
	}

	public void pasteText(int startIndex) throws InvalidComponentException {
		checkIsValid();
		_eText.paste(startIndex);		
	}

	public void replaceText(int startIndex, int endIndex, String s) throws InvalidComponentException {
		checkIsValid();
		_eText.replaceText(startIndex, endIndex, s);
	}

	public void setAttributes(int startIndex, int endIndex, String[] as) throws InvalidComponentException {
		checkIsValid();
		SimpleAttributeSet aset = new SimpleAttributeSet();
		for(int i=0; i<as.length;i++){
			String[] attr = as[i].split("=");
			if(attr!=null){
				aset.addAttribute(new String(attr[0]), new String(attr[1]));
			}
		}
		
		_eText.setAttributes(startIndex, endIndex, aset);
	}

}
