/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.accservice.javapp.adapt;

import java.lang.reflect.Method;

import org.eclipse.actf.accservice.adapt.AccessibilityAdaptor;
import org.eclipse.actf.accservice.core.IAccessibleElement;
import org.eclipse.actf.util.resources.ClassLoaderCache;

/**
 * adaptor implementation for converting nodes in an Eclipse SWT control hierarchy to 
 * instances of <code>IAccessibleElement</code>. 
 * @author Mike Squillace
 *
 */
public class SwtAccessibilityAdaptor extends AccessibilityAdaptor
{

	protected static final ClassLoaderCache CL_CACHE = ClassLoaderCache.getDefault();
	protected static final String CTRL_TYPE_NAME = "org.eclipse.swt.widgets.Control";
	
	/** {@inheritDoc} */
	public Object adapt (Object o, Class type) throws Exception {
		Object result = null;
		if (o != null && CL_CACHE.isInstanceOf(CTRL_TYPE_NAME, o)
				&& IAccessibleElement.class.isAssignableFrom(type)) {
			Method meth = o.getClass().getMethod("isDisposed", (Class[]) null);
			if (!((Boolean) meth.invoke(o, (Object[]) null)).booleanValue()) {
				// TODO assumes SWT on a windows system
				result = createAccessibleElement(o, null, "msaa");
			}
		}
		return result;
	}
	/** {@inheritDoc} */
	/* 
	 public NodeSynchronizer getNodeSynchronizer ()
	 {
	 return new SwtMsaaNodeSynchronizer();
	 }
	 */
}
