/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* IBM Corporation - initial API and implementation
*******************************************************************************/ 
package org.eclipse.actf.model;

import java.io.InputStream;
import java.net.URL;
import java.util.Enumeration;

import org.eclipse.actf.core.ActfCorePlugin;
import org.eclipse.actf.core.config.IConfiguration;
import org.eclipse.actf.util.resources.IResourceLocator;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle
 */
public class ModelPlugin extends ActfCorePlugin {

	// The plug-in ID
	public static final String MODEL_PLUGIN_ID = "org.eclipse.actf.model";
	
	public static final String MODEL_TYPE_EXTENSION = "modelTypes";
	
	//registry things
	private IExtensionRegistry registry;
	private ModelRegistryChangeListener registryListener;
	/**
	 * The constructor
	 */
	public ModelPlugin() {
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);

		Enumeration urls = context.getBundle().findEntries(IResourceLocator.DEFAULT_ACTF_RESOURCES_DIR, IConfiguration.ACTF_ID + ".xml", false);
		while (urls != null && urls.hasMoreElements()) {
			URL url = (URL) urls.nextElement();
			InputStream stream = url.openStream();
			if (stream != null) {
				configuration.addConfigurationData(stream);
				stream.close();
			}
		}

		//set a registry change listener for any future changes
		registry = Platform.getExtensionRegistry();
		registryListener = new ModelRegistryChangeListener();
		if (registry != null && (getPluginId().equals(MODEL_PLUGIN_ID))) {
			registry.addRegistryChangeListener(registryListener);
		}
		
		//add all data from declared entry points
		 IExtensionPoint [] exps = registry.getExtensionPoints(MODEL_PLUGIN_ID);
		 for (int i=0;i<exps.length;i++){
			 IExtension[] extensions = exps[i].getExtensions();
			 for (int j=0; j< extensions.length; j++){
				 configuration.addConfigurationData(extensions[j]);
			 }
			 
		  }
		 IConfigurationElement [] elements = registry.getConfigurationElementsFor(MODEL_PLUGIN_ID, MODEL_TYPE_EXTENSION);
		 for (int i=0;i<elements.length;i++){			
			// force these plugins to load so that they will be found by when the RuleViewer tries to load the rulebases
			String plugin = elements[i].getContributor().getName();
			if (plugin!= null){
				try {
				 Platform.getPlugin(plugin);
				} catch (IllegalStateException ise){
					//this seems to be caused by timing issues and only occurs for Accprobe - no harm done
					//LoggingUtil.println(IReporter.SYSTEM_NONFATAL, "Error loading model from plugin "+plugin);
				}
			}
			
		}		 
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
		if (getPluginId().equals(MODEL_PLUGIN_ID)) {
			if (registry != null && registryListener != null) {
				registry.removeRegistryChangeListener(registryListener);
			}
		}
	}

	protected String getPluginId () {
		return MODEL_PLUGIN_ID;
	}

}
