/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.model.javapp.locate;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.actf.model.javapp.SwingGuiModel;
import org.eclipse.actf.model.locate.AbstractNodeLocator;


/**
 * locates or distinguishes Swing components in a Java GUI for the Swing model during the validation
 * process. All components passed to the implemented methods must be an instance of <code>java.awt.Component</code>.
 *
 * @author Mike Squillace
 */
public class SwingComponentLocator extends AbstractNodeLocator
{

	/**
	 * create a new SwingComponentLocator. By default, the components that can be identified via the
	 * <code>identify</code> method are found in the 'swing.xml' file. The default property used is 'name'.
	 *
	 * @see "resources/swing.xml"
	 */
	public SwingComponentLocator () {
		super("name", SwingGuiModel.SWING_MODEL, new SwingNodePointerFactory());
		propertiesMap = initializeProperties();
	}

	private Map initializeProperties() {
		Map m = new HashMap();
		m.put(javax.swing.AbstractButton.class.getName(), "text");
		m.put(javax.swing.JLabel.class.getName(), "text");
		m.put(javax.swing.JFrame.class.getName(), "title");
		m.put(javax.swing.JInternalFrame.class.getName(), "title");
		return m;
	}

	/**
	 * default children getter for Swing components is <code>getComponents</code>
	 */
	protected String getChildrenMethodName () {
		return "getComponents";
	}
} // SwingComponentLocator
