/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 
package org.eclipse.actf.model.mozdom.locate;

import java.util.Locale;

import org.apache.commons.jxpath.ri.QName;
import org.apache.commons.jxpath.ri.model.NodePointer;
import org.apache.commons.jxpath.ri.model.NodePointerFactory;
import org.mozilla.interfaces.nsIDOMHTMLDocument;
import org.mozilla.interfaces.nsIDOMHTMLElement;
import org.mozilla.interfaces.nsIDOMNode;
import org.mozilla.interfaces.nsISupports;
import org.mozilla.xpcom.XPCOMException;

public class MozillaDomNodePointerFactory implements NodePointerFactory
{

	public static final int MOZDOM_POINTER_FACTORY_ORDER = 3;
	
	public NodePointer createNodePointer(QName name, Object object, Locale locale) {
		return createNodePointer(null, name, object, locale);
	}

	public NodePointer createNodePointer(NodePointer parent, QName name, Object object) {
		return createNodePointer(parent, name, object, null);
	}

	public NodePointer createNodePointer(NodePointer parent, QName name,
										 Object object, Locale locale) {
		NodePointer res = null;
		if (object instanceof nsIDOMNode) {
			res = new MozillaDomNodePointer((nsIDOMNode) object, parent, locale);
		} else if (object instanceof nsISupports) {
			nsIDOMNode node = null;
			try {
				node = (nsIDOMHTMLElement) ((nsISupports) object).queryInterface(nsIDOMHTMLElement.NS_IDOMHTMLELEMENT_IID);
			} catch (XPCOMException e) {
			}
			
			try {
				node = (nsIDOMHTMLDocument) ((nsISupports) object).queryInterface(nsIDOMHTMLDocument.NS_IDOMHTMLDOCUMENT_IID);
			} catch (XPCOMException e) {
			}
			if (node != null) {
				res =new MozillaDomNodePointer(node, parent, locale); 
			}
		}
		
		return res;
	}

	public int getOrder() {
		return MOZDOM_POINTER_FACTORY_ORDER;
	}

}
