/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.core;

/**
 * an execution point triggered by the firing of an event.
 * 
 * @author Mike Squillace
 *
 */
public class EventExecutionPoint extends ExecutionPoint
{

	protected Object event;

	public EventExecutionPoint (String name, String validatorClassName,
								Object target, Object eventObj) {
		super(name, validatorClassName, target);
		event = eventObj;
	}

	public Object getEvent () {
		return event;
	}

	/**
	 * return an ExecutionPoint of the same type but with a different name and
	 * validator class name. This is typically used in the Validation loop where
	 * we have a child class of a compoment that has a different model than
	 * the parent.
	 * @param name
	 * @param validator
	 * @param execPoint
	 * @return a clone of the execution point
	 */
	public ExecutionPoint cloneExecutionPoint (String name, String validator,
												ExecutionPoint execPoint) {
		EventExecutionPoint newExecPoint = null;
		if (execPoint.getClass().isAssignableFrom(this.getClass())) {
			newExecPoint = new EventExecutionPoint(name, validator, execPoint.getTarget(), ((EventExecutionPoint) execPoint).getEvent());
		}else {
			throw new IllegalArgumentException("ExecutionPoint type is not an EventExecutionPoint.");
		}
		return newExecPoint;
	}
}
