/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.core;

import org.eclipse.actf.util.logging.LoggingUtil;

public class ValidationThread extends Thread {

	public static final Object VALIDATION_THREAD_LOCK = new Object();

	public static final ThreadGroup VALIDATION_THREAD_GROUP = new ThreadGroup(
			"ACTF Validation Group");

	private static int count = 0;

	public ValidationThread() {
		this(VALIDATION_THREAD_GROUP, "Validation" + (++count));
	}

	public ValidationThread(Runnable target) {
		this(VALIDATION_THREAD_GROUP, target, "Validation" + (++count));
	}

	public ValidationThread(ThreadGroup group, Runnable target) {
		this(group, target, "Validation#" + (++count));
	}

	public ValidationThread(String name) {
		this(VALIDATION_THREAD_GROUP, name);
	}

	public ValidationThread(ThreadGroup group, String name) {
		this(group, null, name);
	}

	public ValidationThread(Runnable target, String name) {
		this(VALIDATION_THREAD_GROUP, target, name);
	}

	public ValidationThread(ThreadGroup group, Runnable target, String name) {
		super(group, target, name);
		setDaemon(false);
		LoggingUtil.println(LoggingUtil.PROCESS_INFO,
				"Created validation thread: count = " + count);
	}

	public static void decrementThreadCount() {
		synchronized (VALIDATION_THREAD_LOCK) {
			--count;
			VALIDATION_THREAD_LOCK.notifyAll();
			LoggingUtil.println(LoggingUtil.PROCESS_ALL,
					"Validation thread count decremented to " + count);
		}
	}

	public static int getThreadCount() {
		return count;
	}

	public void terminate() {
		interrupt();
		decrementThreadCount();
	}
}
