/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.rulebase;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;


/**
 * implementation for a document rulebase. Note that this is the only type of rulebase currently supported.
 * 
 * @author John Buslawski
 *
 */
public class DocumentRuleBaseDescriptor implements IRuleBaseDescriptor, Serializable
{

	/** indicates the document type of rulebase; value is 'document' */
	public static final String DOCUMENT = "document";

	private String ruleBaseName;
	private String rbFactory;
	private String type;
	private String sourceLocation;
	private Set targets = new HashSet();

	/** {@inheritDoc} */
	public String getRuleBaseName() {
		return ruleBaseName;
	}

	/** {@inheritDoc} */
	public void setRuleBaseName(String ruleBaseName) {
		checkIsValid(ruleBaseName);	
		this.ruleBaseName = ruleBaseName;
	}

	/**
	 * get the location of the document that describes the rulebase
	 * 
	 * @return the sourceLocation
	 */
	public String getSourceLocation() {
		return sourceLocation;
	}

	/**
	 * set the source location of the document that describes the rulebase
	 * 
	 * @param sourceLocation
	 *            the sourceLocation to set
	 */
	public void setSourceLocation(String sourceLocation) {
		checkIsValid(sourceLocation);
		
		this.sourceLocation = sourceLocation;
	}

	/** {@inheritDoc} */
	public String getType() {
		return type;
	}

	/** {@inheritDoc} */
	public void setType(String sourceType) {
		checkIsValid(sourceType);
		type = sourceType;
	}

	/** {@inheritDoc} */
	public String getRuleBaseFactory() {
		return rbFactory;
	}

	/** {@inheritDoc} */
	public void setRuleBaseFactory(String rbFactory) {
		checkIsValid(rbFactory);
		this.rbFactory = rbFactory;
	}

	/**
	 * @return the targets for this rule base mapping
	 */
	public String[] getTargets() {
		return (String[]) targets.toArray(new String[targets.size()]);
	}

	public void setTargets(Set targets) {
		this.targets = targets;
	}
	
	protected void checkIsValid (String param) throws IllegalArgumentException {
		if (param == null || param.trim().length() == 0) {
			throw new IllegalArgumentException("Illegal parameter in IDocumentRuleBase");
		}
	}
	
}
