/*******************************************************************************
 * Copyright (c) 2004, 2008 IBM Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.actf.validation.rulebase;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.Set;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.validation.rules.RuleConstants;
import org.eclipse.actf.validation.valdoc.rulebase.IValidationDocument;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtension;

public class EclipseRuleBaseMap extends RuleBaseMapBuilder {

	private IConfigurationElement[] rulebases = null;

	public EclipseRuleBaseMap(IExtension extension) {
		super(extension);
		rulebases = extension.getConfigurationElements();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.actf.validation.rulebase.RuleBaseMapBuilder#
	 * getRuleBaseDescriptors()
	 */
	@Override
	public IRuleBaseDescriptor[] getRuleBaseDescriptors() {
		if (rulebases != null) {
			ArrayList descriptors = new ArrayList();
			for (int i = 0; i < rulebases.length; i++) {
				if (rulebases[i] instanceof IConfigurationElement) {
					IConfigurationElement element = (IConfigurationElement) rulebases[i]; 
					IRuleBaseDescriptor descriptor = parseRuleBaseDescriptor(element);
					if (descriptor != null) {
						descriptors.add(descriptor);
					}

				}
			}

			return ((IRuleBaseDescriptor[]) descriptors
					.toArray(new IRuleBaseDescriptor[descriptors.size()]));

		} else {
			return null;
		}
	}

	@Override
	protected IRuleBaseDescriptor parseRuleBaseDescriptor(Object document) {
		IConfigurationElement rbElem;
		DocumentRuleBaseDescriptor rbDescriptor = null;
		if (document != null && document instanceof IConfigurationElement){
			rbElem = (IConfigurationElement)document;
			rbDescriptor = new DocumentRuleBaseDescriptor();
			rbDescriptor.setRuleBaseName(rbElem.getAttribute(IValidationDocument.DOCUMENT_NAME)); 		
			String sourceType = rbElem.getAttribute("type");
			if (!sourceType
					.equalsIgnoreCase(DocumentRuleBaseDescriptor.DOCUMENT)) {
				LoggingUtil
						.println(
								IReporter.WARNING,
								"The <actf:type> element found in IRule Base mapping document is not of type - "
										+ DocumentRuleBaseDescriptor.DOCUMENT);
			}
			rbDescriptor.setType(sourceType);
			rbDescriptor.setRuleBaseFactory(rbElem.getAttribute(					
					RuleBaseMapDocument.RULEBASE_FACTORY));
			rbDescriptor.setSourceLocation(rbElem.getAttribute(
					RuleBaseMapDocument.LOCATION));

			Set targetSet = new HashSet();
			IConfigurationElement [] targetElements = rbElem.getChildren("target");
			for (int t = 0; t < targetElements.length; ++t) {
				IConfigurationElement targetElement = targetElements[t];
				String regExpStr = targetElement.getAttribute(
						RuleConstants.REGEXP);
				targetSet.add(regExpStr);
			}
			rbDescriptor.setTargets(targetSet);

		}
		return rbDescriptor;
	}

}
