/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.rulebase;


/**
 * A factory for rules base mappings. A factory instance, once obtained, can be
 * used to find rule base mappings for a given type.
 * 
 * @author John Buslawski
 * 
 */
public interface IRuleBaseMappingFactory {

	/**
	 * gets an instance of the rule base mapping for the given name.
	 * 
	 * @param name -
	 *            name of the rule base mapping
	 * @return the rule base mapping for the given name or null if there was no
	 *         rule base mapping registered under that name
	 */
	public DocumentRuleBaseDescriptor getRuleBaseMapping(String name);

	/**
	 * gets all of the RuleBaseMappings
	 * 
	 * @return all rule base mappings or null if there are no rule base mapping
	 */
	public DocumentRuleBaseDescriptor[] getRuleBaseMappings();
}
