/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.rulebase;

import java.util.Map;

/**
 * implement to associate metadata with a rulebase
 * 
 * @author John Buslawski
 * 
 */
public interface IRuleBaseMetadata {

	/**
	 * @param name
	 *            of metadata attribute
	 * @return value of metadata attribute or <code>null</code> if no name is
	 *         specified
	 */
	public Object getAttribute(String name);

	/**
	 * @param name
	 *            of metadata attribute
	 * @param value
	 *            of metadata attribute
	 */
	public void setAttribute(String name, Object value);

	/**
	 * get all attribute names of this metadata object
	 * 
	 * @return attribute names or empty array if this metadata object is empty
	 */
	public String[] getAttributeNames();

	/**
	 * return the attributes of this metadata object
	 * 
	 * @return all attributes of this metadata object
	 */
	public Map getAttributes();

	/**
	 * set the attributes for this metadata object
	 * 
	 * @param attributes
	 */
	public void setAttributes(Map attributes);

	/**
	 * clear all attributes from this metadata object
	 * 
	 * 
	 */
	public void clear();

	/*
	 * @return size of metadata attribute Map
	 */
	public int size();
}
