/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* IBM Corporation - initial API and implementation
*******************************************************************************/ 
package org.eclipse.actf.validation.rulebase;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.validation.valdoc.rulebase.DocumentRuleBaseBuilder;

public class ValidationDocumentUtils {
	
	enum RuleBaseName {
		IBM_JAVA_ACCESSIBILITY_CHECKLIST("IBM Java Accessibility Checklist"),
		IBM_SOFTWARE_ACCESSIBILITY_CHECKLIST("IBM Software Accessibility Checklist"),
		IBM_WEB_ACCESSIBILITY_CHECKLIST("IBM Web Accessibility Checklist");		
		
		private String rbName;
		
		RuleBaseName(String name) {
			rbName = name;
		}
		
		public String getRBName() {
			return rbName;
		}
	}
	
	enum TargetExpressions {
		SWING_TARGET_EXPR1("java\\.awt\\..+"),
		SWING_TARGET_EXPR2("javax\\.swing\\..+"),
		SWT_TARGET_EXPR1("org\\.eclipse\\.swt\\..+"),
		WEB_TARGET_EXPR1("org\\.mozilla\\.interfaces\\.nsI.+");
		
		private String targetExpr;
		
		TargetExpressions(String targetExpression) {
			targetExpr = targetExpression;
		}
		
		public String getTargetExpr() {
			return targetExpr;
		}
	}
	
	
	
	/**
	 * Add a validation document for validation
	 * @param ruleBaseName - Name of the rulebase in the validation document,
	 * 		the name must not be <code>null</code>.  
	 * @param sourceLoc - source location of the document that describes the rulebase
	 * @param targetExpressions - Target Expressions for this rulebase mapping
	 * Eg: For web validation
	 * 	ruleBaseName : RuleBaseName.IBM_WEB_ACCESSIBILITY_CHECKLIST.rbName
	 *  sourceLoc : Relative path: resources/existingdom_accessibility.xml or 
	 *  			Absolute Path pointing to exact location on disk
	 *  targetExpressions - Array of {TargetExpressions.SWING_TARGET_EXPR1.targetExpr, TargetExpressions.SWING_TARGET_EXPR2.targetExpr}
	 */
	public static void addValidationDocument(String ruleBaseName, String sourceLoc,
			String[] targetExpressions) {
		LoggingUtil.println(LoggingUtil.ALL, "***** Adding Validation Document "+ruleBaseName+" Initiated *****");
		RuleBaseManager rbm = RuleBaseManager.getInstance();
		DocumentRuleBaseDescriptor rd = new DocumentRuleBaseDescriptor();
		rd.setRuleBaseName(ruleBaseName);
		rd.setType(DocumentRuleBaseDescriptor.DOCUMENT);// only valid type for now
		rd.setRuleBaseFactory(DocumentRuleBaseBuilder.class.getName());
		Set<String> targets = new HashSet<String>();
		targets.addAll(Arrays.asList(targetExpressions));
		rd.setTargets(targets);
		rd.setSourceLocation(sourceLoc);
		rbm.addRuleBase(rd);	
		LoggingUtil.println(LoggingUtil.ALL, "***** Valiation Document "+ruleBaseName+ " Add Successful *****");

	}

	/**
	 * Removes validation document from validation
	 * @param ruleBaseName - Name of the rulebase, The name must not be <code>null</code>
	 */
	public static void removeValidationDocument(String ruleBaseName) {
		LoggingUtil.println(LoggingUtil.ALL, "***** Removing Validation Document "+ruleBaseName+" Initiated *****");
		RuleBaseManager rbm = RuleBaseManager.getInstance();
//		rbm.getRuleBase(ruleBaseName).setEnabled(false);
		rbm.removeRuleBase(ruleBaseName);
		rbm.removeRuleBaseDescr(ruleBaseName);
//		rbm.removeLinksToTarget(targetName);
		LoggingUtil.println(LoggingUtil.ALL, "***** Valiation Document "+ruleBaseName+ " Removal Complete *****");
	}
	
}
