/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.rules;

import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.validation.validators.IValidationContext;
import org.w3c.dom.Element;

/**
 * embodies the actf:and rule
 * 
 */
public class AndRule extends AbstractRule {

	/** {@inheritDoc} */
	public void initialize(Object content) throws Exception {
		if (content instanceof Element) {
			processActfAttributes((Element) content);
		}
	}

	/** {@inheritDoc} */
	public boolean apply(IValidationContext context, Object target) throws Exception {
		// execute the presence test
		boolean result = super.apply(context, target);
		// if not enabled, presence test failed,
		// or is ignoring null target, then return
		if (isEnabled() && result && !isIgnoringNullTarget(target)) {
			// Process all rules and "and" the results together.
			// if an application fails, we stop immediately
			
			List criteria = Arrays.asList(getParts());
			for (Iterator iter = criteria.iterator(); result && iter.hasNext(); ) {
				ICriterion criterionTemp = (ICriterion) iter.next();
				if(criterionTemp instanceof IRule) {
					try {
						result &= ((IRule)criterionTemp).apply(context, target);
					} catch (Exception e) {
						LoggingUtil.println(IReporter.SYSTEM_NONFATAL,
								"Exception caught while validating rule " + getName() + " for target object " + target.getClass().getName(), e);
					}
				}
			}			
		}

		return result;
	}
}
