/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
* 
* Contributors:
* 	IBM Corporation - Initial  API
* *******************************************************************************/ 
package org.eclipse.actf.validation.rules;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.validation.validators.IValidationContext;

/**
 * When there are children for a criterion, they are tested with compound 
 * criterion. It like an AND check.
 * Not used yet...Will need to test it once markup is finalized.  
 */
public class CompoundCriterion extends AbstractCriterion {

	List<ICriterion> criterionList = new ArrayList<ICriterion>();
	
	public CompoundCriterion(ICriterion[] criterion) {
		criterionList = Arrays.asList(criterion);
	}
	
	public boolean apply(IValidationContext context, Object target)
			throws Exception {
		boolean result = true;
		
		for (Iterator<ICriterion> iter = criterionList.iterator(); result && iter.hasNext(); ) {
			ICriterion criterionTemp = (ICriterion) iter.next();
			try {
				result &= criterionTemp.apply(context, target);
			} catch (Exception e) {
				LoggingUtil.println(IReporter.SYSTEM_NONFATAL,
						"Exception caught while validating criterion rule " + ((IRule)criterionTemp).getName() + 
						" for target object " + target.getClass().getName(), e);
			}
		}	
		return result;
	}

	public void initialize(Object content) throws Exception {
		//Nothing to do here
	}

}
