/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.rules;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.util.resources.ClassLoaderCache;
import org.eclipse.actf.validation.valdoc.rulebase.IValidationDocument;
import org.eclipse.actf.validation.validators.IValidationContext;
import org.w3c.dom.Element;

/**
 * embodies actf:instanceof rule
 * 
 * @author John Buslawski
 * 
 */
public class InstanceofRule extends AbstractRule {

	private String className = null;

	/** {@inheritDoc} */
	public void initialize(Object content) throws Exception {
		if (content instanceof Element) {
			processActfAttributes((Element) content);
			String name = ((Element) content)
					.getAttributeNS(IValidationDocument.ACTF_NAMESPACE_URI, RuleConstants.INSTANCEOF);
			className = getAliasValue(name);
		}
	}

	/** {@inheritDoc} */
	public boolean apply(IValidationContext context, Object target) throws Exception {
		// execute the presence test
		boolean result = super.apply(context, target);
		// if not enabled or if presence test failed then return
		if (isEnabled() && result && !isIgnoringNullTarget(target)
					&& className != null && target != null) {
			LoggingUtil.println(IReporter.DETAIL,
					"InstanceofRule.apply(Object) - className = " + className + ", name of target = " + target.getClass().getName());
			try {
				Class targetClass = ClassLoaderCache.getDefault().classForName(getAliasValue(className));
				if (targetClass != null) {
					LoggingUtil.println(IReporter.DETAIL,
							"InstanceofRule.apply(Object) - targetClass.getName() = " + targetClass.getName());
					if (!targetClass.isAssignableFrom(target.getClass())) {
						LoggingUtil.println(IReporter.DETAIL,
								"InstanceofRule.apply(Object) - !targetClass.isAssignableFrom(target.getClass()), constructing message.");
						String message = findMessage();
						if (message == null || message.length() == 0) {
							StringBuffer msgBuff = new StringBuffer();
							msgBuff.append("Component is of type ");
							msgBuff.append(target.getClass().getName());
							msgBuff.append("; object of type ");
							msgBuff.append(targetClass.getName());
							message = msgBuff.toString();
						}
						
						report(context, message);
						result = false;
					} else {
						LoggingUtil.println(IReporter.DETAIL,
								"InstanceofRule.apply(Object) - targetClass.isAssignableFrom(target.getClass()) is true, exiting.");
					}
				} else {
					LoggingUtil.println(IReporter.WARNING, "targetClass " + className + " for instanceof test not found ");
				}
			} catch (Exception e) {
				LoggingUtil.println(IReporter.SYSTEM_NONFATAL,
						"Exception caught while validating rule "
						+ getName() + " for target object "
						+ target.getClass().getName(), e);
			}
		}
		
		return result;
	}
}
