/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
* 
* Contributors:
* 	IBM Corporation - Initial  API
*******************************************************************************/

package org.eclipse.actf.validation.rules;

import org.eclipse.actf.model.DefaultModelFactory;
import org.eclipse.actf.model.IModel;
import org.eclipse.actf.validation.valdoc.rulebase.IValidationDocument;
import org.eclipse.actf.validation.validators.IValidationContext;
import org.w3c.dom.Element;

public class NodeNameCriterion extends AbstractCriterion {

	private String nodeName;
	private IModel model;
	
	public String getTargetNodeName () {
		return nodeName;
	}
	
	public boolean apply(IValidationContext context, Object target) throws Exception {
		String targetNodeName = model.getNodeName(target);
		return targetNodeName != null && targetNodeName.equals(nodeName);
	}

	public void initialize(Object content) throws Exception {
		if(content instanceof Element) {
			Element elem = (Element) content;
			boolean isActfNamespace = elem.getNamespaceURI() != null 
				&& elem.getNamespaceURI().equals(IValidationDocument.ACTF_NAMESPACE_URI);
			nodeName = !isActfNamespace ? elem.getLocalName() : "";
		}
		model = DefaultModelFactory.getInstance().resolveModel(ruleSet.getRuleBase().getModelType());
	}

}
