/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.rules;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.validation.reports.ValidationReportRecord;
import org.eclipse.actf.validation.reports.ValidationReporter;
import org.eclipse.actf.validation.validators.IValidationContext;
import org.eclipse.actf.validation.validators.ValidationContextConstants;
import org.w3c.dom.Element;

/**
 * the actf:or rule
 * 
 * @author John Buslawski
 * 
 */
public class OrRule extends AbstractRule {

	/** {@inheritDoc} */
	public void initialize(Object content) throws Exception {
		if (content instanceof Element) {
			processActfAttributes((Element) content);
		}
	}

	/** {@inheritDoc} */
	public boolean apply(IValidationContext context, Object target) throws Exception {
		// execute the presence test
		boolean result = super.apply(context, target);
		// if not enabled, presence test failed,
		// or ignoring null target, then return
		if (isEnabled() && result && !isIgnoringNullTarget(target)) {
			IReporter oldReporter = (IReporter) context.getParameter(ValidationContextConstants.REPORTER);
			ValidationReporter tmpReporter = new ValidationReporter();
			tmpReporter.setDefaultOutputLevel(oldReporter.getDefaultOutputLevel());
			tmpReporter.setSourceID(oldReporter.getSourceID());
			tmpReporter.open();
			tmpReporter.startCategory(getComponentCategory());
			tmpReporter.startReport(target);
			context.setParameter(ValidationContextConstants.REPORTER, tmpReporter);
			result = false;
			ArrayList<ICriterion> criterion = new ArrayList<ICriterion>(Arrays.asList(getParts()));

			for (Iterator<ICriterion> iter = criterion.iterator(); !result && iter.hasNext(); ) {
				ICriterion criterionTemp = (ICriterion) iter.next();
				if(criterionTemp instanceof IRule) {
					IRule rule = (IRule) criterionTemp;
					try {
						result = result || rule.apply(context, target);
					} catch (Exception e) {
						LoggingUtil.println(IReporter.SYSTEM_NONFATAL,
								"Exception caught while validating rule "
								+ getName() + " for target object " + target.getClass().getName(), e);
					}
				}
			}
			
			tmpReporter.endReport();
			if (!result) {
				ValidationReportRecord[] records = tmpReporter.lastReport();
				ValidationReportRecord lastRecord = null;
				for (int r = 0; r < records.length; ++r) {
					if (oldReporter instanceof ValidationReporter && !records[r].equals(lastRecord)) {
						((ValidationReporter) oldReporter).addReportRecord(records[r]);
						lastRecord = records[r];
					}
				}
			}
			
			context.setParameter(ValidationContextConstants.REPORTER, oldReporter);
		}

		return result;
	}
	
}
