/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.dialogs;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.regex.Matcher;

import org.eclipse.actf.model.locate.AbstractNodeLocator;
import org.eclipse.actf.validation.reports.CreationContext;
import org.eclipse.actf.validation.reports.ValidationReportRecord;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;


public class ReportRecordDetailsDialog extends BaseRecordDetailsDialog
{

	private CreationContext context;

	public ReportRecordDetailsDialog (Shell parent, String title, Image image,
										ValidationReportRecord record,
										CreationContext context) {
		super(parent, title, image, record);
		this.context = context;
	}

	protected Control createRecordDetails (Composite parent) {
		// Create the details area.
		Composite panel = new Composite(parent, SWT.NONE);
		panel.setLayoutData(new GridData(GridData.FILL_BOTH));
		GridLayout layout = new GridLayout();
		layout.marginHeight = convertHorizontalDLUsToPixels(IDialogConstants.VERTICAL_MARGIN);
		layout.marginWidth = convertHorizontalDLUsToPixels(IDialogConstants.HORIZONTAL_MARGIN);
		panel.setLayout(layout);
		Composite composite = new Composite(panel, SWT.NULL);
		composite.setLayoutData(new GridData());
		layout = new GridLayout();
		layout.numColumns = 2;
		composite.setLayout(layout);
		new Label(composite, SWT.NONE).setText(REPORT_CLASS_NAME);
		new Text(composite, SWT.NONE | SWT.READ_ONLY).setText(record.getNodeName());
		new Label(composite, SWT.NONE).setText(REPORT_COMPONENT_LABEL);
		new Text(composite, SWT.NONE | SWT.READ_ONLY).setText(record.getComponentName());
		new Label(composite, SWT.NONE).setText(REPORT_COMPONENT_PATH);
		new Text(composite, SWT.READ_ONLY | SWT.MULTI).setText(formatLocationPath(record.getLocationPath()));
		if (record.getLongMessage() != null) {
			new Label(composite, SWT.NONE).setText(REPORT_DETAIL_MESSAGE);
			new Text(composite, SWT.NONE | SWT.READ_ONLY | SWT.MULTI).setText(record.getLongMessage());
		}
		new Label(composite, SWT.NONE).setText(REPORT_TIME_STAMP);
		new Text(composite, SWT.NONE | SWT.READ_ONLY).setText(record.getAttributeAsString(ValidationReportRecord.TIMESTAMP_FIELDNAME));
		if (context == null) { return panel; }
		Label separator = new Label(panel, SWT.SEPARATOR | SWT.HORIZONTAL);
		//Label separator = new Label(composite, SWT.SEPARATOR | SWT.HORIZONTAL);
		GridData gd = new GridData();
		gd.horizontalSpan = 2;
		gd.horizontalAlignment = GridData.FILL;
		separator.setLayoutData(gd);
		Label traceLabel = new Label(panel, SWT.NONE);
		traceLabel.setText(REPORT_CONTEXT_TRACE);
		gd = new GridData();
		gd.horizontalSpan = 2;
		traceLabel.setLayoutData(gd);
		Text text = new Text(panel, SWT.MULTI | SWT.READ_ONLY | SWT.BORDER
				| SWT.H_SCROLL | SWT.V_SCROLL);
		text.setLayoutData(new GridData(GridData.FILL_BOTH));
		// Create the content.
		StringWriter writer = new StringWriter(1000);
		appendMessage(new PrintWriter(writer), context.getMember().toString());
		appendStackTrace(new PrintWriter(writer), context.getStackTrace());
		text.setText(writer.toString());
		return panel;
	}
	
	private String formatLocationPath (String path) {
		StringBuffer sb = new StringBuffer();
		int indent = 0;
		Matcher matcher = AbstractNodeLocator.SEGMENT_PATTERN.matcher(path);
		while (matcher.find()) {
			for (int i = 0; i < indent; ++i) {
				sb.append("  ");
			}
			sb.append(path.substring(matcher.start(), matcher.end()));
			sb.append('\n');
			++indent;
		}
		return sb.toString().replace("getNodeId($" + AbstractNodeLocator.NODELOCATOR_VARIABLE + ")", "@name");
	}

	public static void appendMessage (PrintWriter writer, String msg) {
		writer.println(msg);
	}

	public static void appendStackTrace (PrintWriter writer,
											StackTraceElement[] trace) {
		for (int i = 0; i < trace.length; i++) {
			appendMessage(writer, trace[i].toString());
		}
	}
}
