/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.filters;

import org.eclipse.actf.validation.reports.ValidationReport;
import org.eclipse.actf.validation.reports.ValidationReportRecord;
import org.eclipse.actf.validation.ui.ValidationUIConstants;
import org.eclipse.actf.validation.ui.ValidationUiPlugin;
import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerFilter;


public class SeverityFilter extends ViewerFilter
{

	public static final String[] severityKeys = {
			"CONFIG", "DETAIL", "INFO", "WARNING", "ERROR", "SEVERE"};

	//initialize default severities
	protected boolean[] sevFilters = {false, false, true, true, true, false};

	protected boolean settingsSaved = false;

	public SeverityFilter () {
		getCurrentFilterSettings();
	}

	public void getCurrentFilterSettings () {
		IDialogSettings settings = ValidationUiPlugin.getDefault().getDialogSettings();
		try {
			if (settings.getBoolean(ValidationUIConstants.KEY_SEVERITY_FILTERS_SAVED)) {
				sevFilters[0] = settings.getBoolean(ValidationUIConstants.KEY_SEV_CONFIG);
				sevFilters[1] = settings.getBoolean(ValidationUIConstants.KEY_SEV_DETAIL);
				sevFilters[2] = settings.getBoolean(ValidationUIConstants.KEY_SEV_INFO);
				sevFilters[3] = settings.getBoolean(ValidationUIConstants.KEY_SEV_WARNING);
				sevFilters[4] = settings.getBoolean(ValidationUIConstants.KEY_SEV_ERROR);
				sevFilters[5] = settings.getBoolean(ValidationUIConstants.KEY_SEV_SEVERE);
			}else {
				setDefaults();
			}
		}catch (Exception e) {
			setDefaults();
		}
	}

	private void setDefaults () {
		sevFilters[0] = false; //config
		sevFilters[1] = false; //detail
		sevFilters[2] = true;  //info
		sevFilters[3] = true;  //warning
		sevFilters[4] = true;  //error
		sevFilters[5] = false; //severe
	}

	public boolean select (Viewer viewer, Object parentElement, Object element) {
		boolean result = false;
		if (element instanceof ValidationReport) {
			result = true;
		}else if (element instanceof ValidationReportRecord) {
			String sev = ((ValidationReportRecord) element).getLevelAsString();
			if (sev != null) {
				for (int i = 0; i < severityKeys.length; i++) {
					if (severityKeys[i].equals(sev)) {
						result = sevFilters[i];
						break;
					}
				}
			}
		}
		return result;
	}

	public boolean isFilterProperty (Object element, String property) {
		return property.equals("severity");
	}

	public static int categorize (String sev) {
		int cat = -1;
		for (int i = 0; cat < 0 && i < severityKeys.length; i++) {
			if (severityKeys[i].equals(sev)) {
				cat = severityKeys.length - i;
			}
		}
		return cat;
	}
}
