/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.jobs;

import java.util.LinkedList;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.validation.events.IReportListener;
import org.eclipse.actf.validation.events.ReportEvent;
import org.eclipse.actf.validation.reports.CreationContext;
import org.eclipse.actf.validation.reports.ValidationReport;
import org.eclipse.actf.validation.reports.ValidationReportRecord;
import org.eclipse.actf.validation.ui.ValidationUiPlugin;
import org.eclipse.actf.validation.ui.views.AbstractViewPart;
import org.eclipse.ui.PlatformUI;

public class ValidationReportListener implements IReportListener
{

	private LinkedList reports;

	private ValidationReport guiValReport;

	private int ctxCount;

	private String source = null;

	public ValidationReportListener () {
		reports = new LinkedList();
		reports.add(new ValidationReport());
		guiValReport = new ValidationReport();
		guiValReport.setDescription("<starting>");
		AbstractViewPart.setReportViewInput(guiValReport);
	}

	public void reportStarted (ReportEvent e) {
		if (source != null) {
			guiValReport.setSource(source);
			guiValReport.setDescription("<executing>" + source);
			AbstractViewPart.setReportViewInput(guiValReport);
		}
	}

	public void reportCompleted (ReportEvent e) {
		final ValidationReportRecord[] records = e.getReportRecords();
		ValidationReport report = (ValidationReport) reports.getLast();
		report.setReportID(e.getReportID());
		report.addRecords(records);
		reports.add(new ValidationReport());
		trace(IReporter.DETAIL, "\nreportCompleted(ReportEvent), added "
				+ records.length + " records");
		for (int r = 0; r < records.length; ++r) {
			trace(IReporter.CONFIG, records[r].toString());
		}
		PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {

			public void run () {
				guiValReport.addRecords(records);
			}
		});
		if (source != null) {
			guiValReport.setSource(source);
			guiValReport.setDescription("<terminated>" + source);
			AbstractViewPart.setReportViewInput(guiValReport);
		}
	}

	public void creationContextStarted (ReportEvent e) {
	}

	public void creationContextCompleted (ReportEvent e) {
		final CreationContext[] contexts = e.getCreationContexts();
		((ValidationReport) reports.getLast()).addCreationContexts(contexts);
		ctxCount += contexts.length;
		trace(
			IReporter.DETAIL,
			"\ncreation contexts completed(ReportEvent), added "
					+ contexts.length + " contexts");
		
		for (int r = 0; r < contexts.length; ++r) {
			trace(IReporter.CONFIG, contexts[r].toString());
		}
		PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {

			public void run () {
				guiValReport.addCreationContexts(contexts);
			}
		});
	}

	public ValidationReport[] getAllReports () {
		return (ValidationReport[]) reports.toArray(new ValidationReport[reports.size()]);
	}

	protected void trace (int level, String msg) {
		ValidationUiPlugin.getDefault().trace(level, msg);
	}

	public String get_source () {
		return source;
	}

	public void set_source (String source) {
		this.source = source;
	}
}
