/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.preferences;

import java.io.File;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.dialogs.TitleAreaDialog;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.layout.FormLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.List;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

public class PathEditor extends org.eclipse.jface.preference.PathEditor
{

	protected String pathString, labelString;

	protected String lastPath;

	protected int limit = -1; // unlimited

	/**
	 * @return Returns the limit.
	 */
	public int getLimit () {
		return limit;
	}

	protected PathEditor () {
		super();
	}

	public PathEditor (String name, String pathString, String fieldLabelString,
						String chooserLabelString, Composite parent) {
		this(name, pathString, fieldLabelString, chooserLabelString, -1, parent);
	}

	public PathEditor (String name, String fieldlabelString, Composite parent) {
		this(name, "", fieldlabelString, "", parent);
	}

	public PathEditor (String name, String pathString, String fieldLabelString,
						String chooserLabelString, int limit, Composite parent) {
		super(name, fieldLabelString, chooserLabelString, parent);
		this.pathString = pathString;
		this.labelString = chooserLabelString;
		this.limit = limit;
	}

	protected Button newButton, removeButton;

	protected Button upButton, downButton;

	protected List list;

	/* (non-Javadoc)
	 * Method declared on FieldEditor.
	 */
	protected void doFillIntoGrid (Composite parent, int numColumns) {
		super.doFillIntoGrid(parent, numColumns);
		Control[] children = parent.getChildren();
		// find the List and select buttons
		// *** depends on screen order ***
		for (int i = 0; i < children.length; i++) {
			Control control = children[i];
			if (control instanceof List) {
				list = (List) control;
			}else if (control instanceof Composite) {
				Composite c = (Composite) control;
				Control[] xchildren = c.getChildren();
				for (int j = 0; j < xchildren.length; j++) {
					Control control2 = xchildren[j];
					if (control2 instanceof Button) {
						Button b = (Button) control2;
						switch (j) {
						case 0:
							newButton = b;
							break;
						case 1:
							removeButton = b;
							break;
						case 2:
							upButton = b;
							break;
						case 3:
							downButton = b;
							break;
						}
					}
				}
			}
		}
		if (newButton != null && removeButton != null) {
			newButton.addSelectionListener(new SelectionAdapter() {

				public void widgetSelected (SelectionEvent e) {
					if (limit >= 0) {
						newButton.setEnabled(list.getItemCount() < limit);
					}
				}
			});
			removeButton.addSelectionListener(new SelectionAdapter() {

				public void widgetSelected (SelectionEvent e) {
					if (limit >= 0) {
						newButton.setEnabled(list.getItemCount() < limit);
					}
				}
			});
		}
		setEditEnable();
	}

	public void updateButtonEnablement () {
		if (limit >= 0) {
			newButton.setEnabled(list.getItemCount() < limit);
		}
	}

	protected static void configureLayout (Control c, FormAttachment left,
											FormAttachment top,
											FormAttachment right,
											FormAttachment bottom) {
		FormData fd = new FormData();
		if (left != null) {
			fd.left = left;
		}
		if (top != null) {
			fd.top = top;
		}
		if (right != null) {
			fd.right = right;
		}
		if (bottom != null) {
			fd.bottom = bottom;
		}
		c.setLayoutData(fd);
	}

	protected class PathDialog extends TitleAreaDialog
	{

	
		Text label;

		Button fileButton, dirButton;

		Composite comp;

		public PathDialog (Shell shell) {
			super(shell);
		}

		protected Control createDialogArea (Composite parent) {
			Composite xcomp = (Composite) super.createDialogArea(parent);
			getShell().setText("Path Selector");
			setTitle("Select a path");
			comp = new Composite(xcomp, SWT.NONE);
			comp.setLayoutData(new GridData(GridData.FILL_BOTH));
			comp.setLayout(new FormLayout());
			label = new Text(comp, SWT.SINGLE);
			label.addModifyListener(new ModifyListener() {

				public void modifyText (ModifyEvent e) {
					lastPath = label.getText();
				}
			});
			label.setText(pathString);
			fileButton = new Button(comp, SWT.PUSH);
			fileButton.setText("File...");
			fileButton.setToolTipText("Select a file path");
			fileButton.addSelectionListener(new SelectionAdapter() {

				public void widgetSelected (SelectionEvent e) {
					FileDialog fd = new FileDialog(getShell(), SWT.OPEN);
					if (lastPath != null) {
						if (new File(lastPath).exists()) {
							fd.setFilterPath(lastPath);
						}
					}
					lastPath = null;
					String path = fd.open();
					if (path != null) {
						path = path.trim();
						if (path.length() > 0) {
							lastPath = path;
							label.setText(path);
							//comp.pack();
						}
					}
				}
			});
			dirButton = new Button(comp, SWT.PUSH);
			dirButton.setText("Directory...");
			dirButton.setToolTipText("Select a directory path");
			dirButton.addSelectionListener(new SelectionAdapter() {

				public void widgetSelected (SelectionEvent e) {
					DirectoryDialog dd = new DirectoryDialog(getShell());
					if (labelString != null) {
						dd.setMessage(labelString);
					}
					if (lastPath != null) {
						if (new File(lastPath).exists()) {
							dd.setFilterPath(lastPath);
						}
					}
					lastPath = null;
					String path = dd.open();
					if (path != null) {
						path = path.trim();
						if (path.length() > 0) {
							lastPath = path;
							label.setText(path);
							//comp.pack();
						}
					}
				}
			});
			configureLayout(
				label, new FormAttachment(0, 5), new FormAttachment(0, 5),
				new FormAttachment(100, -5), null);
			configureLayout(
				fileButton, new FormAttachment(0, 5),
				new FormAttachment(label, 5), null, null);
			configureLayout(
				dirButton, new FormAttachment(fileButton, 5),
				new FormAttachment(label, 5), null, null);
			return xcomp;
		}
	}

	/* (non-Javadoc)
	 * Method declared on ListEditor.
	 * Creates a new path element by means of a PathDialog.
	 */
	protected String getNewInputObject () {
		PathDialog pd = new PathDialog(getShell());
		int rc = pd.open();
		return rc == 0 ? lastPath : null;
	}

	/*
	 protected String[] parseString(String stringList) {
	 System.out.println("parseString: " + stringList);
	 String[] sa = super.parseString(stringList);
	 return sa;
	 }
	 */
	protected void doLoad () {
		super.doLoad();
		updateButtonEnablement();
	}

	protected void doLoadDefault () {
		super.doLoadDefault();
		updateButtonEnablement();
	}

	protected void setStdButtonEnable () {
		int sidx = list.getSelectionIndex();
		removeButton.setEnabled(sidx >= 0);
		upButton.setEnabled(sidx >= 0);
		downButton.setEnabled(sidx >= 0);
	}

	protected void setEditEnable () {
		int sidx = list.getSelectionIndex();
		editButton.setEnabled(sidx >= 0);
	}

	protected Composite buttonBox;

	protected Button editButton;

	public Composite getButtonBoxControl (Composite parent) {
		Composite xbuttonBox = super.getButtonBoxControl(parent);
		if (buttonBox == null) {
			buttonBox = xbuttonBox;
			editButton = new Button(buttonBox, SWT.PUSH);
			editButton.setText("Edit");
			editButton.setFont(parent.getFont());
			GridData data = new GridData(GridData.FILL_HORIZONTAL);
			data.heightHint = convertVerticalDLUsToPixels(
				editButton, IDialogConstants.BUTTON_HEIGHT);
			int widthHint = convertHorizontalDLUsToPixels(
				editButton, IDialogConstants.BUTTON_WIDTH);
			data.widthHint = Math.max(widthHint, editButton.computeSize(
				SWT.DEFAULT, SWT.DEFAULT, true).x);
			editButton.setLayoutData(data);
			editButton.addSelectionListener(new SelectionAdapter() {

				public void widgetSelected (SelectionEvent e) {
					int sidx = list.getSelectionIndex();
					if (sidx >= 0) {
						pathString = list.getItem(sidx);
						PathDialog id = new PathDialog(getShell());
						int rc = id.open();
						if (rc == Window.OK) {
							list.remove(sidx);
							list.add(lastPath, sidx);
						}
					}
					setStdButtonEnable();
					setEditEnable();
				}
			});
		}
		return xbuttonBox;
	}

	public List getListControl (Composite parent) {
		list = super.getListControl(parent);
		list.addSelectionListener(new SelectionAdapter() {

			public void widgetSelected (SelectionEvent e) {
				setEditEnable();
			}
		});
		return list;
	}
}
