/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.providers;

import org.eclipse.actf.validation.reports.ValidationReportRecord;
import org.eclipse.actf.validation.ui.ISeverityColorProvider;
import org.eclipse.jface.viewers.IColorProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Table;


public class MessageTableLabelProvider extends LabelProvider
	implements IColorProvider, ITableLabelProvider
{

	protected Table t;

	protected ISeverityProvider sevProvider;

	protected ISeverityColorProvider colorProvider;

	public static final int SEVERITY_COLUMN = 0;
	public static final int MESSAGE_COLUMN = SEVERITY_COLUMN + 1;
	public static final int COMPONENT_COLUMN = MESSAGE_COLUMN + 1;
	public static final int ID = COMPONENT_COLUMN + 1;
	
	public MessageTableLabelProvider (Table t, ISeverityProvider sp, ISeverityColorProvider cp) {
		this.t = t;
		this.sevProvider = sp;
		this.colorProvider = cp;
	}

	public Color getForeground (Object element) {
		return colorProvider.getNormalForegroundColor(t);
	}

	public Color getBackground (Object element) {
		Color result = colorProvider.getNormalBackgroundColor(t);
		String sev = getColumnText(element, SEVERITY_COLUMN);
		int posn = -1;
		String[] sevKeys = sevProvider.getSeverityKeys();
		for (int i = 0; posn < 0 && i < sevKeys.length; i++) {
			if (sevKeys[i].equals(sev)) {
				posn = i;
			}
		}
		if (posn >= sevProvider.getInfoSeverity()) {
			result = colorProvider.getInfoBackgroundColor(t);
		}
		if (posn >= sevProvider.getWarningSeverity()) {
			result = colorProvider.getWarningBackgroundColor(t);
		}
		if (posn >= sevProvider.getErrorSeverity()) {
			result = colorProvider.getErrorBackgroundColor(t);
		}
		return result;
	}

	public Image getColumnImage (Object element, int columnIndex) {
		return null;
	}

	public String getColumnText (Object element, int columnIndex) {
		String result = "";
		if (element instanceof ValidationReportRecord) {
			ValidationReportRecord record = (ValidationReportRecord) element;
			switch (columnIndex) {
			case SEVERITY_COLUMN:
				result = record.getLevelAsString();
				break;
			case MESSAGE_COLUMN:
				result = record.getMessage();
				break;
			case COMPONENT_COLUMN:
				String comp = record.getComponentName();
				String cls = record.getNodeName();
				if (comp != null && comp.trim().length() > 0
						&& !comp.equals("<None>")) {
					result = cls + ":" + comp;
				}else {
					result = cls;
				}
				break;
			case ID:
				result = record.getRuleId();
				break;
			}
		}
		return result;
	}
}
