/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.providers;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.actf.validation.events.IReportGroupModifyListener;
import org.eclipse.actf.validation.events.ReportGroupModifyEvent;
import org.eclipse.actf.validation.reports.ValidationReport;
import org.eclipse.actf.validation.reports.ValidationReportGroup;
import org.eclipse.actf.validation.reports.ValidationReportRecord;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;


public class ReportManagerContentProvider extends ArrayContentProvider
	implements ITreeContentProvider, IReportGroupModifyListener
{

	private TreeViewer viewer;

	private ValidationReportGroup group;

	private Map recordMap = new HashMap();

	public Object[] getElements (Object input) {
		return getChildren(input);
	}

	public Object[] getChildren (Object parentElement) {
		Object[] result = null;
		if (parentElement instanceof ValidationReport) {
			result = ((ValidationReport) parentElement).getRecords();
		}else if (parentElement instanceof ValidationReportGroup) {
			result = ((ValidationReportGroup) parentElement).getReports();
		}
		return result == null ? new Object[0] : result;
	}

	public Object getParent (Object element) {
		Object result = null;
		if (element instanceof ValidationReportRecord) {
			String id = (String) recordMap.get(element);
			if (id != null) {
				result = group.getReport(id);
			}
		}else if (element instanceof ValidationReport) {
			if (group.getReport(((ValidationReport) element).getReportID()) != null) {
				result = group;
			}
		}
		return result;
	}

	public boolean hasChildren (Object element) {
		boolean result = false;
		if (element instanceof ValidationReport) {
			//report has no visible children
		}else if (element instanceof ValidationReportGroup) {
			result = ((ValidationReportGroup) element).getReports().length > 0;
		}
		return result;
	}

	public void inputChanged (Viewer viewer, Object oldInput, Object newInput) {
		this.viewer = (TreeViewer) viewer;
		if (oldInput != null) {
			((ValidationReportGroup) oldInput).removeReportGroupModifyListener(this);
		}
		if (newInput != null) {
			recordMap.clear();
			group = (ValidationReportGroup) newInput;
			group.addReportGroupModifyListener(this);
		}
	}

	public void reportGroupModified (ReportGroupModifyEvent e) {
		if (e.op == ReportGroupModifyEvent.REPORTS_ADDED
				&& e.reports instanceof ValidationReport[]) {
			viewer.add(group, e.reports);
			viewer.setSelection(new StructuredSelection(e.reports), true);
			for (int r = 0; r < e.reports.length; ++r) {
				ValidationReport report = e.reports[r];
				ValidationReportRecord[] records = report.getRecords();
				for (int rr = 0; rr < records.length; ++rr) {
					recordMap.put(records[rr], report.getReportID());
				}
				viewer.add(report, records);
			}
		}else if (e.op == ReportGroupModifyEvent.REPORTS_REMOVED
				&& e.reports instanceof ValidationReport[]) {
			viewer.remove(e.reports);
		}
	}
}
