/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html

* Contributors: IBM Corporation - Initial API
********************************************************************************/ 

package org.eclipse.actf.validation.ui.providers;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.eclipse.actf.validation.rulebase.IRuleBase;
import org.eclipse.actf.validation.rules.ICriterion;
import org.eclipse.actf.validation.rules.ICriterionMapping;
import org.eclipse.actf.validation.rules.IRule;
import org.eclipse.actf.validation.rules.IRuleSet;
import org.eclipse.actf.validation.valdoc.rulebase.ValidationDocumentRuleSet;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

public class RuleBaseContentProvider implements ITreeContentProvider {
	Map<ICriterion, List<IRule>> criteriaRulesMap;

	public RuleBaseContentProvider() {
		super();
	}
	
	// TODO AKF - new structure is Checklist(Rulebase)>Checkpoint>Checkpoint
	// subpoint.....
	public Object[] getChildren(Object parentElement) {
		Object[] object = new Object[0];
		if (parentElement instanceof IRuleBase) {
			IRuleSet[] ruleSets = ((IRuleBase) parentElement).getRuleSets();
			for (int i = 0; i < ruleSets.length; i++) {
				ValidationDocumentRuleSet vdocRuleSet = (ValidationDocumentRuleSet) ruleSets[i];
				ICriterionMapping criterionMapping = vdocRuleSet
						.getCriterionMap();
				criteriaRulesMap = criterionMapping.getAllRules();
				List<IRule> rulesList = new ArrayList<IRule>();
				for (Iterator iter = criteriaRulesMap.entrySet().iterator(); iter
						.hasNext();) {
					Map.Entry entry = (Map.Entry) iter.next();
					//ICriterion criterion = (ICriterion) entry.getKey();
					List<IRule> rules = (List<IRule>)entry.getValue();
					rulesList.addAll(rules);
					if (rulesList != null) {
						object = new Object[rulesList.size()];
						object = rulesList.toArray();
					}
				}

			}
		} 
		//TODO AKF - do we really need these (Rule parts)?
		/*else if (parentElement instanceof IRule) {
			List<ICriterion> ruleParts = Arrays.asList(((IRule) parentElement).getParts());
			object = new Object[ruleParts.size()];
			object = ruleParts.toArray();
		}*/
		return object;
	}

	public Object getParent (Object element) {
		Object obj = null;
		if(element instanceof IRuleBase) {
			obj = null;
		//} else if (element instanceof IRuleSet) {
		//	obj = ((IRuleSet) element).getRuleBase();
		} else if(element instanceof IRule) {
			obj = ((IRule)element).getParent();
		//} else if (element instanceof AbstractCriterion) {
		//	obj = ((AbstractCriterion) element).getRuleSet();
		} 
		return obj;
	}

	public boolean hasChildren (Object element) {
		Object[] obj = getChildren(element);
		boolean result =  obj == null ? false : obj.length>0;
		return result;
	}

	public Object[] getElements (Object inputElement) {
		ArrayList rBases = (ArrayList)inputElement;
		return rBases.toArray();
	}

	public void dispose () {
		//Nothing to dispose
	}

	public void inputChanged (Viewer viewer, Object oldInput, Object newInput) {
		//Nothing to change
	}
	
}
