/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html

* Contributors: Initial API - Ann Ford
*	
*******************************************************************************/
package org.eclipse.actf.validation.ui.views;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.validation.rules.IRule;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.forms.IFormPart;
import org.eclipse.ui.forms.widgets.Section;
import org.eclipse.ui.forms.widgets.TableWrapData;
import org.eclipse.ui.forms.widgets.TableWrapLayout;

public class RuleDetailsPage extends AbstractDetailsPage {
	private Text idText;
	private Text severityText;
	private Text messageText;
	private Text longDescriptionText;

	//private Text rulesetText;
	//private Text repairHintText;

	public void createContents(Composite parent) {
		TableWrapLayout layout = new TableWrapLayout();
		layout.topMargin = 5;
		layout.leftMargin = 5;
		layout.rightMargin = 2;
		layout.bottomMargin = 2;
		parent.setLayout(layout);

		toolkit = mform.getToolkit();
		Section section = toolkit.createSection(parent, Section.TITLE_BAR);
		section.marginWidth = 10;
		section.setText("Rule Details");
		TableWrapData td = new TableWrapData(TableWrapData.FILL,
				TableWrapData.TOP);
		td.grabHorizontal = true;
		section.setLayoutData(td);
		Composite client = toolkit.createComposite(section);
		GridLayout glayout = new GridLayout();
		glayout.marginWidth = glayout.marginHeight = 0;
		glayout.numColumns = 2;
		client.setLayout(glayout);

		idText = createLabelText(client, "ID", "");
		idText.setEditable(false);
		severityText = createLabelText(client, "Severity", "");
		severityText.setEditable(false);
		messageText = createLabelText(client, "Message", "");
		messageText.setEditable(false);
		messageText.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		longDescriptionText = createLabelText(client, "Long Description", "");
		longDescriptionText.setEditable(false);
		//repairHintText = createLabelText(client, "Repair Hint", "");
		//repairHintText.setEditable(false);
		//rulesetText = createLabelText(client, "Ruleset", "");
		//rulesetText.setEditable(false);

		toolkit.paintBordersFor(section);
		section.setClient(client);

	}

	@Override
	public void selectionChanged(IFormPart part, ISelection selection) {
		IStructuredSelection ssel = (IStructuredSelection) selection;

		if (ssel.size() == 1) {
			IRule rule = (IRule) ssel.getFirstElement();

			if (rule != null) {
				idText.setText(rule.getId() == null ? "" : rule.getId());
				String severity = getSeverity(rule);
				severityText.setText(severity == null ? "" : severity);
				messageText.setText(rule.getMessage() == null ? "" : rule
						.getMessage());
				longDescriptionText
						.setText(rule.getLongDescription() == null ? "" : rule
								.getLongDescription());
				// These aren't very useful right now - will leave them here for later
				/*repairHintText.setText(rule.getRepairHint() == null ? "" : rule
						.getRepairHint());
				IRuleSet ruleSet = rule.getRuleSet();
				if (ruleSet != null) {
					rulesetText.setText(ruleSet.getName() == null ? ""
							: ruleSet.getName());
				}*/
			}
		}
	}

	public void refresh() {
		// TODO Auto-generated method stub

	}

	private String getSeverity(IRule rule) {
		String levelStr = "";
		if (rule != null) {
			int iSev = rule.getSeverity();
			if (iSev >= 0) {
				int lastDot = IReporter.KEYS[iSev].lastIndexOf('.');
				levelStr = IReporter.KEYS[iSev].substring(lastDot + 1);
			}
		}
		return levelStr;

	}
}
