/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.ui.views;

import java.awt.Component;
import java.awt.Container;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.actf.util.resources.ClassLoaderCache;
import org.eclipse.actf.validation.ui.ValidationUiPlugin;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Widget;


/**
 * @author barryf
 *
 */
public class ViewUtils
{

	protected static ValidationUiPlugin plugin = ValidationUiPlugin.getDefault();

	//protected static final String OBJECT_ID_INTRO = "-@";
	protected static final String OBJECT_ID_INTRO = "@";
	protected static Class ACCELEMENT_TYPE = ClassLoaderCache.getDefault().classForName("org.eclipse.actf.accservice.core.IAccessibleElement");

	public static String removeObjectId (String s) {
		int posn = s.indexOf(OBJECT_ID_INTRO);
		if (posn >= 0) {
			while (posn > 0 && s.charAt(posn - 1) == '-') { // can have leading '-'
				posn--;
			}
			s = s.substring(0, posn);
		}
		return s;
	}

	public static String toHexObjectId (String s) {
		int posn = s.indexOf(OBJECT_ID_INTRO);
		if (posn >= 0) {
			String sid = s.substring(posn + 1);
			try {
				int id = Integer.parseInt(sid);
				String xid = Integer.toHexString(id).toUpperCase();
				xid = "00000000".substring(0, 8 - xid.length()) + xid;
				s = s.substring(0, posn + 1) + xid;
			}catch (Exception e) {
			}
		}
		return s;
	}

	public static String getObjectId (String s) {
		String r = null;
		int posn = s.indexOf(OBJECT_ID_INTRO);
		if (posn >= 0) {
			r = s.substring(posn + OBJECT_ID_INTRO.length());
		}
		return r;
	}

	protected static final String[] saType = new String[0];

	public static String[] split (String key, char delim) {
		List l = new ArrayList();
		int pposn = 0;
		for (int posn = key.indexOf(delim, 0); posn >= 0; pposn = posn + 1, posn = key.indexOf(
			'.', posn + 1)) {
			l.add(key.substring(pposn, posn));
		}
		l.add(key.substring(pposn));
		return (String[]) l.toArray(saType);
	}

	public static String wordCase (String s) {
		if (s.length() > 0) {
			s = s.toLowerCase();
			s = Character.toUpperCase(s.charAt(0)) + s.substring(1);
		}
		return s;
	}

	public static int getLine (String id, XmlNode node) {
		int posn = id.indexOf('@'); // remove any id value
		if (posn >= 0) {
			id = id.substring(0, posn);
		}
		while (id.endsWith("-")) {
			id = id.substring(0, id.length() - 1);
		}
		int result = -1;
		if (node != null) {
			//System.out.println("matching: " + id + "<=>" + node.id + "=" + node.line);
			if (node.id != null && node.id.equals(id)) {
				result = node.line;
			}
			if (result < 0) {
				XmlNode[] children = node.getChildrenAsArray();
				for (int i = 0; result < 0 && i < children.length; i++) {
					result = getLine(id, children[i]);
				}
			}
		}
		//System.out.println("getLine " + id + "," + node + ": " + result);
		return result;
	}

	public static final String ACCESSIBLE_IMAGE_NAME = "accessible";

	public static final String COMPONENT_IMAGE_NAME = "component";

	public static final String CONTAINER_IMAGE_NAME = "container";

	public static Image getImageForElement (Object element, int index) {
		Image i = null;
		//if (index <= 0) {       // no column or first column
		String id = null;
		// *** consider adding more type specific icons ***
		if (element instanceof Container) {
			id = CONTAINER_IMAGE_NAME;
		}else if (element instanceof Component) {
			id = COMPONENT_IMAGE_NAME;
		}else if (element instanceof Composite) {
			id = CONTAINER_IMAGE_NAME;
		}else if (element instanceof Control) {
			id = COMPONENT_IMAGE_NAME;
		}else if (element instanceof Widget) {
			id = COMPONENT_IMAGE_NAME;
		}else if (ACCELEMENT_TYPE != null && ACCELEMENT_TYPE.isAssignableFrom(element.getClass())) {
			id = ACCESSIBLE_IMAGE_NAME;
		}
		i = id != null ? getRegisteredImage(id) : i;
		//trace("getImageForElement " + index + " " + element + ": " + i);
		//}
		return i;
	}

	public static Image getRegisteredImage (String key) {
		return plugin.getRegisteredImage(key);
	}

	public static int indexOfIgnoreCase (List l, String s) {
		int res = -1;
		for (int i = 0; res < 0 && i < l.size(); i++) {
			String item = ((String) l.get(i)).replace('\\', '/');
			s = s.replace('\\', '/');
			if (item.equalsIgnoreCase(s)) {
				res = i;
			}
		}
		return res;
	}

	public static int indexOfIgnoreCase (String[] l, String s) {
		int res = -1;
		for (int i = 0; res < 0 && i < l.length; i++) {
			if (l[i].equalsIgnoreCase(s)) {
				res = i;
			}
		}
		return res;
	}
}
