/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html

* Contributors: Initial API - Ann Ford
*	
*******************************************************************************/
package org.eclipse.actf.validation.ui.wizards;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

public class RulebaseRemoteFilePage extends WizardPage {

	public static final String PAGE_NAME = "Remote File";
	private Text remoteFileText = null;
	private boolean saved = false;

	protected RulebaseRemoteFilePage() {
		super(PAGE_NAME);
		setTitle("File Located on a remote website");
		setDescription("Enter the URL of the new rulebase file in the form of 'http://www.ibm.com/rulebase.zip'.");
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		GridLayout layout = new GridLayout(3, false);
		composite.setLayout(layout);

		Label remoteFileLabel = new Label(composite, SWT.LEFT);
		remoteFileLabel.setText("Web address (URL)");
		remoteFileText = new Text(composite, SWT.SINGLE);
		remoteFileText
				.setToolTipText("Enter the web address of the new rulebase file");
		GridData data = new GridData(GridData.FILL_HORIZONTAL);
		remoteFileText.setLayoutData(data);
		remoteFileText.addModifyListener(new ModifyListener() {

			public void modifyText(ModifyEvent e) {
				if (remoteFileText != null) {
					String text = remoteFileText.getText();
					if (text != null && text.trim().length() > 0) {
						saveData();
						getWizard().getContainer().updateButtons();
					}
				}

			}

		});

		setControl(composite);
	}

	@Override
	public IWizardPage getNextPage() {
		return getWizard().getPage(TargetLocationPage.PAGE_NAME);
	}

	@Override
	public boolean canFlipToNextPage() {
		return saved;

	}

	@Override
	public boolean isPageComplete() {
		return saved;
	}

	private void saveData() {
		LoadRulebaseWizard wizard = (LoadRulebaseWizard) getWizard();
		URL url = null;
		try {
			String address = remoteFileText.getText();
			if (address.toLowerCase().endsWith(".xml") || address.toLowerCase().endsWith(".zip")) {
				url = new URL(address);
				setErrorMessage(null);
				wizard.setSourceURL(url);
				saved = true;
			} else {
				setErrorMessage("Remote rulebase file needs to be either ZIP or XML");
			}

		} catch (MalformedURLException e) {
			setErrorMessage("This is not a valid URL. Please Enter a valid web address.");
			saved = false;
		}
	}

}
