/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html

* Contributors: Initial API - Ann Ford
*	
*******************************************************************************/
package org.eclipse.actf.validation.ui.wizards;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;

public class RulebaseSourcePage extends WizardPage {
	private Button localButton = null;
	private Button remoteButton = null;
	private boolean saved = false;
	

	public RulebaseSourcePage() {
		super("Rulebase Source");
		setTitle("Rulebase Source Location");
		setDescription("Select the location of the rulebase file to add.");
		setPageComplete(true);
	}

	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayoutData(new GridData(GridData.FILL_BOTH));
		GridLayout layout = new GridLayout(3, false);
		composite.setLayout(layout);

		// Row 1 - Rulebase location (group containing: radio button group for
		// either URL or Local file

		Group locationGroup = new Group(composite, SWT.SHADOW_ETCHED_IN);
		locationGroup.setLayout(new RowLayout(SWT.HORIZONTAL));
		locationGroup.setText("Rulebase Location");
		GridData data = new GridData(GridData.FILL_HORIZONTAL);
		data.horizontalSpan = 2;
		locationGroup.setLayoutData(data);
		localButton = new Button(locationGroup, SWT.RADIO);
		localButton.setText("Local file system");
		localButton
				.setToolTipText("Choose this if the new rulebase is on the local file system");
		SelectionListener localButtonListener = new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				saveData();
				getWizard().getContainer().updateButtons();
			}
		};

		localButton.addSelectionListener(localButtonListener);

		remoteButton = new Button(locationGroup, SWT.RADIO);
		remoteButton.setText("URL");
		remoteButton
				.setToolTipText("Choose this if the new rulebase is on a webpage");
		SelectionListener remoteButtonListener = new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				saveData();
				getWizard().getContainer().updateButtons();
			}
		};
		remoteButton.addSelectionListener(remoteButtonListener);
		setControl(composite);
	}

	@Override
	public IWizardPage getNextPage() {
		
		if (localButton != null && localButton.getSelection()) {
			return getWizard().getPage(RulebaseLocalFilePage.PAGE_NAME);
		} else
			return getWizard().getPage(RulebaseRemoteFilePage.PAGE_NAME);
	}


	@Override
	public boolean canFlipToNextPage() {
		return saved;

	}

	@Override
	public boolean isPageComplete() {
		return saved;
	}
	private void saveData() {
		LoadRulebaseWizard wizard = (LoadRulebaseWizard) getWizard();
		wizard.setIsFileLocal(localButton.getSelection());
		saved = true;
		
	}


}
