/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.valdoc.codeproc;

import org.eclipse.actf.model.IModel;

/**
 * Implementations of this interface retreave the desired ICodeProcessor based
 * upon the language and model being used as given in the
 * actf:scriptlang and actf:model attribute values of the
 * &lt;rulebase&gt; element.
 * 
 * @author Mike Squillace
 */
public interface ICodeProcessorFactory {

	/**
	 * retrieve a ICodeProcessor for the given language. ACTF currently supports
	 * the following scripting languages:
	 * 
	 * <p>
	 * <ul>
	 * <li>Rhino/JavaScript</li>
	 * </ul>
	 * 
	 * <p>
	 * If the actf:scriptlang attribute value is set to 'java' and/or
	 * actf:class and actf:package attributes are provided, then the
	 * ICodeProcessor returned is a CodeCompiler object so that Java code may be
	 * embedded in the XML document.
	 * 
	 * @param lang --
	 *            language for which a AbstractCodeInterpreter is to be
	 *            instantiated
	 * @param model --
	 *            model for which code interpreter is to be built
	 * @return code processor
	 * @see "resources/actf.xml"
	 */
	public ICodeProcessor getCodeProcessor(String lang, IModel model);
} // ICodeProcessorFactory
