/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
* IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.valdoc.rulebase;

/**
 * base element class for element within a validation document
 * 
 * @author <a href="mailto:masquill@us.ibm.com">Mike Squillace</a>
 *
 */
public abstract class BaseElement
{
	
	protected String name;
	protected String text;
	
	/**
	 * create an element or descriptor for an element in a validation document
	 * 
	 * @param name name attribute (if present)
	 * @param text text content (if any)
	 */
	public BaseElement (String name, String text) {
		this.name = name;
		this.text = text == null ? "" : text;
	}
	
	/**
	 * returns the name attribute of the element (if present)
	 * 
	 * @return name attribute
	 */
	public String getName () {
		return name;
	}

	/**
	 * returns the text content of the element (if present)
	 * 
	 * @return text content or empty string if no content is present
	 */
	public String getText () {
		return text;
	}

	/**
	 * returns the trimmed text content of the element
	 * 
	 * @return trimmed textual content of element
	 */
	public String getTextTrim () {
		return text.trim();
	}

}
