/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.valdoc.rulebase;

import java.util.List;
import java.util.Map;
import java.util.Set;

import org.eclipse.actf.validation.rules.ICriterion;
import org.eclipse.actf.validation.rules.ICriterionMapping;
import org.eclipse.actf.validation.rules.IRule;


public class ValidationDocumentCriterionMapping implements ICriterionMapping {

	private Map<ICriterion, List<IRule>> criteriaRulesMap;
	private Set polymorphicRuleTypes;
	private Set nonPolymorphicRuleTypes;

	public ValidationDocumentCriterionMapping(Map<ICriterion, List<IRule>> criteriaRulesMap,
											  Set polyRuleTypes, Set nonPolyRuleTypes) {
		this.criteriaRulesMap = criteriaRulesMap;
		polymorphicRuleTypes = polyRuleTypes;
		nonPolymorphicRuleTypes = nonPolyRuleTypes;
	}

	public Set getNonPolymorphicRuleTypes() {
		return nonPolymorphicRuleTypes;
	}

	public Set getPolymorphicRuleTypes() {
		return polymorphicRuleTypes;
	}

	public void setNonPolymorphicRuleTypes(Set ruleTypes) {
		nonPolymorphicRuleTypes = ruleTypes;
	}

	public void setPolymorphicRuleTypes(Set ruleTypes) {
		polymorphicRuleTypes = ruleTypes;
	}

	public Map<ICriterion, List<IRule>> getAllRules() {
		return criteriaRulesMap;
	}
	
	public void setAllRules(Map<ICriterion, List<IRule>> rules) {
		criteriaRulesMap.putAll(rules);
	}
	
	public ICriterion[] getCriteria() {
		Set criteriaKeys = criteriaRulesMap.keySet();
		return (ICriterion[])criteriaKeys.toArray(new ICriterion[criteriaKeys.size()]);		
	}

	public ICriterion[] getRulesForCriterion(ICriterion criterion) {
		return (ICriterion[])((List<IRule>)criteriaRulesMap.get(criterion)).toArray(new ICriterion[0]);		
	}
	
}
