/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.valdoc.rulebase;

import java.net.URL;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import org.eclipse.actf.model.IModel;
import org.eclipse.actf.validation.core.ExecutionPointDescriptor;
import org.eclipse.actf.validation.rulebase.IDocumentRuleBase;
import org.eclipse.actf.validation.rulebase.IRuleBaseMetadata;
import org.eclipse.actf.validation.rules.IRuleSet;
import org.eclipse.actf.validation.valdoc.codeproc.ICodeProcessor;

public class ValidationDocumentRuleBase implements IDocumentRuleBase {

	private URL docLocation = null;
	private String modelType = null;
	private String name = null;
	private String scriptLang = null;
	private HashMap ruleSets = new HashMap();
	private IRuleBaseMetadata rbMetadata = null;
	private boolean enabled = false;
	private IModel model = null;
	private ICodeProcessor codeProc = null;
	private HashMap execPtDescriptors = new HashMap();
	String version = null;

	public ValidationDocumentRuleBase() {
	}

	public URL getDocumentLocation() {
		return docLocation;
	}

	public void setDocumentLocation(URL location) {
		docLocation = location;
		
	}
	public void addRuleSet(IRuleSet set) {
		if (set != null) {
			ruleSets.put(set.getName(), set);
		}
	}

	public String getModelType() {
		return modelType;
	}

	public IRuleBaseMetadata getMetadata() {
		return rbMetadata;
	}

	public String getName() {
		return name;
	}

	public IRuleSet[] getRuleSets() {
		return (IRuleSet[]) ruleSets.values().toArray(new IRuleSet[ruleSets.size()]);
	}

	public boolean isEnabled() {
		return enabled;
	}

	public void removeRuleSet(String name) {
		if (ruleSets.containsKey(name)) {
			ruleSets.remove(name);
		}
	}

	public void setModelType(String type) {
		modelType = type;
	}

	public void setEnabled(boolean enable) {
		enabled = enable;
	}

	public void setMetadata(IRuleBaseMetadata metadata) {
		rbMetadata = metadata;
	}

	public void setName(String name) {
		this.name = name;
	}

	public void setRuleSets(IRuleSet[] rulesets) {
		if (rulesets != null) {
			for (int i = 0; i < rulesets.length; i++) {
				addRuleSet(rulesets[i]);
			}
		}
	}

	public String getScriptingLanguage() {
		return scriptLang;
	}

	public void setScriptingLanguage(String lang) {
		scriptLang = lang;
	}

	public void setCodeProcessor(ICodeProcessor codeProc) {
		this.codeProc = codeProc;
	}

	public ICodeProcessor getCodeProcessor() {
		return codeProc;
	}

	public void setModel(IModel model) {
		this.model = model;
	}

	public IModel getModel() {
		return model;
	}

	public ExecutionPointDescriptor[] getExecutionPointDescriptors() {
		return (ExecutionPointDescriptor[]) execPtDescriptors.values().toArray(new ExecutionPointDescriptor[execPtDescriptors.size()]);
	}

	public void setExecutionPointDescriptors(ExecutionPointDescriptor[] descriptors) {
		if (descriptors != null) {
			for (int i = 0; i < descriptors.length; i++) {
				addExecutionPointDescriptor(descriptors[i]);
			}
		}
	}

	public void addExecutionPointDescriptor(ExecutionPointDescriptor descriptor) {
		execPtDescriptors.put(descriptor.getName(), descriptor);
	}

	public void removeExecutionPointDescriptor(String name) {
		if (execPtDescriptors.containsKey(name)) {
			execPtDescriptors.remove(name);
		}
	}

	public ExecutionPointDescriptor getExecutionPointDescriptor(String name) {
		return (ExecutionPointDescriptor) execPtDescriptors.get(name);
	}

	public IRuleSet[] getRuleSetsForExecutionPoint(String name) {
		List ruleSets = new LinkedList();
		Iterator iter = this.ruleSets.keySet().iterator();
		while (iter.hasNext()) {
			String key = (String) iter.next();
			IRuleSet rs = (IRuleSet) this.ruleSets.get(key);
			if (rs.getExecutionPointName().equals(name)) {
				ruleSets.add(rs);
			}
		}
		return (IRuleSet[]) ruleSets.toArray(new IRuleSet[ruleSets.size()]);
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
		
	}
}
