/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.validators;

import java.util.HashMap;

import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;

/**
 * base implementation for all ValidationContexts instances in ACTF.
 * 
 * @author John Buslawski
 */
public abstract class AbstractValidationContext implements IValidationContext,
		Cloneable {

	protected HashMap contextMap = new HashMap();

	// empty ctor
	public AbstractValidationContext() {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.actf.validation.validators.IValidationContext#getParameter(java.lang.String)
	 */
	public Object getParameter(String name) {
		return contextMap.get(name);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.actf.validation.validators.IValidationContext#setParameter(java.lang.String,
	 *      java.lang.Object)
	 */
	public void setParameter(String name, Object value) {
		if (name != null && name.length() > 0) {
			contextMap.put(name, value);
		} else {
			LoggingUtil
					.println(IReporter.SYSTEM_NONFATAL,
							"Null name parameter AccessibilityValidationContext.setParameter().");
			return;
		}
	}

	/**
	 * 
	 */
	public Object clone() {
		AbstractValidationContext ctxCopy = null;
		try {
			ctxCopy = (AbstractValidationContext) super.clone();
		} catch (CloneNotSupportedException e) {
			// this should never happen
			throw new InternalError(e.toString());
		}
		ctxCopy.contextMap = (HashMap) contextMap.clone();
		return ctxCopy;
	}
}
