/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.validators;

/**
 * interface to be implemented by users who wish to implement their own
 * IValidator classes. The IValidationContext is intended to be a wrapper for all
 * items, besides a IRuleSet or set of Rules, necessary to validate a component.
 * Examples include IRuleBase configuration settings, global configuration
 * settings, etc.
 * 
 * @author John Buslawski
 */
public interface IValidationContext {

	/**
	 * sets the parameter to be stored in the IValidationContext
	 * 
	 * @param name --
	 *            name of the parameter as a String
	 * @param value --
	 *            the value of the parameter
	 */
	public void setParameter(String name, Object value);

	/**
	 * gets the parameter keyed by the name
	 * 
	 * @param name --
	 *            name of the parameter as a String
	 * @return the value of the parameter
	 */
	public Object getParameter(String name);
}
