/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.validation.validators;

/**
 * A factory for validation context instances. A factory instance, once
 * obtained, can be used to create validation contexts for a given type.
 * 
 */
public interface IValidationContextFactory {

	/**
	 * registers a validation context for the given type
	 * 
	 * @param name -
	 *            name under which the context is being registered
	 * @param contextClassName -
	 *            the class name of the context implementation
	 */
	public void registerContextClassName(String name, String contextClassName);

	/**
	 * registers a validation context for the validation process type
	 * 
	 * @param processName -
	 *            validation process name under which the context is being
	 *            registered
	 * @param contextClassName -
	 *            the class name of the context implementation
	 */
	public void registerContextByProcessName(String processName,
			String contextClassName);

	/**
	 * gets an instance of the validation context for the given name. The
	 * context must have been previously registered via the
	 * <code>registerContextClassName</code> method.
	 * 
	 * @param name -
	 *            name of the validation context
	 * @return the registered conetxt for the given name or null if there was no
	 *         context registered under that name
	 */
	public IValidationContext getContextInstance(String name);

	/**
	 * creates and initialized a validation context for the given validation
	 * process name. The context must have been previously registered via the
	 * <code>registerContextClassName</code> method.
	 * 
	 * @param procName -
	 *            name of the validation process
	 * 
	 * @return the registered validation context for the given process name or
	 *         null if there was no conext registered under that name
	 */
	public IValidationContext getContextByProcessName(String procName);
}
