/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.webelo.ui.browser;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.StringTokenizer;

import org.eclipse.actf.validation.ui.GuiUtils;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.GroupMarker;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import org.eclipse.actf.webelo.ui.MozillaValidationPreferenceInitializer;
import org.eclipse.actf.webelo.ui.MozillaValidationUIPlugin;

public class BrowserNavigationBar extends Composite
{

	public static final String NAVIGATION_GROUP_ID = "navigationGroup";
	public static final String VALIDATION_GROUP_ID = "validationGroup";

	public static final String BACK_ACTION_ID = "backAction";
	public static final String FORWARD_ACTION_ID = "fwdAction";
	public static final String REFRESH_ACTION_ID = "refreshAction";
	public static final String STOP_ACTION_ID = "stopAction";
	public static final String GO_ACTION_ID = "goAction";

	public static final String AUTOVALIDATE_ACTION_ID = "autoValidateToggleAction";

		protected static final String HISTORY_DELIMITER = "#*#";

	protected ArrayList history;
	protected Combo location;
	protected ToolBarManager toolbarMgr;

	public BrowserNavigationBar (Composite parent, int style) {
		super(parent, style);
		setLayout(new GridLayout(2, false));
		createControl();
	}

	public void enableActions () {
		String url = getUrl();
		IContributionItem item = toolbarMgr.find(BACK_ACTION_ID);
		if (item != null) {
			((ActionContributionItem) item).getAction().setEnabled(
				!history.isEmpty() && history.indexOf(url) > 0);
		}
		item = toolbarMgr.find(FORWARD_ACTION_ID);
		if (item != null) {
			((ActionContributionItem) item).getAction().setEnabled(
				!history.isEmpty() && history.indexOf(url) < history.size() - 1);
		}
	}

	public void addAction (IAction action, String groupId) {
		IContributionItem item = toolbarMgr.find(action.getId());
		if (item != null) {
			toolbarMgr.remove(item);
		}
		toolbarMgr.add(action);
		toolbarMgr.update(true);
	}

	public String getUrl () {
		int sel = location.getSelectionIndex();
		return sel == -1 ? location.getText() : location.getItem(sel);
	}

	public void setUrl (String url) {
		try {
			if (url != null) {
				location.setText(url);
				doGoAction();
			}
		}catch (Exception e) {
			// *** may need to check for not founds and route them to the status line ***
			MozillaValidationUIPlugin.getDefault().logException("Error during page load", e);
		}
	}

	protected void createControl () {
		GridData tgd = new GridData(GridData.FILL_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_CENTER);
		tgd.horizontalSpan = 2;
		toolbarMgr = new ToolBarManager(SWT.FLAT | SWT.HORIZONTAL);
		toolbarMgr.createControl(this);
		toolbarMgr.getControl().setLayoutData(tgd);
		toolbarMgr.add(new GroupMarker(NAVIGATION_GROUP_ID));
		toolbarMgr.add(new GroupMarker(VALIDATION_GROUP_ID));
		Label addrLabel = new Label(this, SWT.RIGHT);
		addrLabel.setText("Address:");
		addrLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_BEGINNING
				| GridData.VERTICAL_ALIGN_CENTER));
		location = new Combo(this, SWT.BORDER);
		location.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		GuiUtils.configureControl(
			location, "locationText", "Enter the new page location to view");
		GuiUtils.configureCommand(location, new SelectionAdapter() {

			public void widgetDefaultSelected (SelectionEvent e) {
				//				ValidationJob job = new ValidationJob(ValidationUIConstants.WEB_VALIDATION_JOB_NAME);
				//				job.setSourcePart((ValidatableGuiContainer) enclosingPart);
				//				if (enclosingPart instanceof ValidatableGuiContainer) {
				//					((ValidatableGuiContainer) enclosingPart).setValidationJob(job);
				//				}
				//				setLocation(location.getText());
				setUrl(location.getText());
			}
		});
		loadHistory();
	}

	public void updateLocation (String url) {
		int index = location.indexOf(url);
		if (index == -1) {
			location.add(url, 0);
			index = 0;
			saveHistory();
		}
		location.select(index);
	}

	public String[] getHistoryItems () {
		return (String[]) history.toArray(new String[history.size()]);
	}

	public void updateHistory (String url) {
		if (history == null) {
			loadHistory();
		}
		int index = 0;
		boolean found = false;
		for (Iterator iter = history.iterator(); !found & iter.hasNext(); ++index) {
			String histItem = (String) iter.next();
			if (histItem.equals(url)) {
				iter.remove();
				found = true;
			}
		}
		int maxHistory = MozillaValidationUIPlugin.getDefault().getPreferenceStore()
			.getInt(MozillaValidationPreferenceInitializer.P_BROWSER_MAX_HISTORY);
		if (history.size() > maxHistory) {
			history.remove(history.size() - 1);
		}
		history.add(0, url);
		saveHistory();
		enableActions();
	}

	protected void saveHistory () {
		String[] items = (String[]) history.toArray(new String[history.size()]);
		String cur = location.getText();
		StringBuffer sb = new StringBuffer(cur);
		for (int h = 0; h < items.length; ++h) {
			sb.append(HISTORY_DELIMITER);
			sb.append(items[h]);
		}
		MozillaValidationUIPlugin.getDefault().getPreferenceStore().setValue(
			MozillaValidationPreferenceInitializer.P_BROWSER_HISTORY_LIST, sb.toString());
		MozillaValidationUIPlugin.getDefault().savePluginPreferences();
		location.setItems(items);
		location.setText(cur);
	}

	protected void loadHistory () {
		String historyPref = MozillaValidationUIPlugin.getDefault().getPreferenceStore()
			.getString(MozillaValidationPreferenceInitializer.P_BROWSER_HISTORY_LIST);
		StringTokenizer st = new StringTokenizer(historyPref, HISTORY_DELIMITER);
		history = new ArrayList();
		while (st.hasMoreTokens()) {
			history.add(st.nextToken());
		}
		location.setItems((String[]) history.toArray(new String[history.size()]));
	}

	protected void doGoAction () {
		IContributionItem goAction = toolbarMgr.find(GO_ACTION_ID);
		if (goAction != null) {
			((ActionContributionItem) goAction).getAction().run();
		}
	}
}
