/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.webelo.ui.browser;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.actf.model.DefaultModelFactory;
import org.eclipse.actf.model.mozdom.MozillaDomBrowserGuiModel;
import org.eclipse.actf.util.logging.IReporter;
import org.eclipse.actf.util.logging.LoggingUtil;
import org.eclipse.actf.validation.ui.jobs.ValidationJob;
import org.eclipse.actf.webelo.ui.MozillaValidationUIPlugin;
import org.eclipse.swt.SWT;
import org.eclipse.swt.browser.Browser;
import org.eclipse.swt.browser.CloseWindowListener;
import org.eclipse.swt.browser.ProgressEvent;
import org.eclipse.swt.browser.WindowEvent;
import org.eclipse.swt.internal.win32.OS;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.mozilla.interfaces.nsIComponentManager;
import org.mozilla.interfaces.nsIDOMDocument;
import org.mozilla.interfaces.nsIDOMElement;
import org.mozilla.interfaces.nsIDOMEvent;
import org.mozilla.interfaces.nsIDOMEventListener;
import org.mozilla.interfaces.nsIDOMEventTarget;
import org.mozilla.interfaces.nsIDOMHTMLElement;
import org.mozilla.interfaces.nsIDOMMutationEvent;
import org.mozilla.interfaces.nsIDOMWindow;
import org.mozilla.interfaces.nsIIOService;
import org.mozilla.interfaces.nsIInterfaceRequestor;
import org.mozilla.interfaces.nsIRequest;
import org.mozilla.interfaces.nsISHEntry;
import org.mozilla.interfaces.nsISHistory;
import org.mozilla.interfaces.nsISHistoryInternal;
import org.mozilla.interfaces.nsISHistoryListener;
import org.mozilla.interfaces.nsISupports;
import org.mozilla.interfaces.nsIURI;
import org.mozilla.interfaces.nsIWebBrowser;
import org.mozilla.interfaces.nsIWebNavigation;
import org.mozilla.interfaces.nsIWebProgress;
import org.mozilla.interfaces.nsIWebProgressListener;
import org.mozilla.xpcom.Mozilla;
import org.mozilla.xpcom.XPCOMException;

public class MozillaDomBrowserControl extends BrowserControl
	implements nsISHistoryListener, nsIWebProgressListener,
	nsIInterfaceRequestor
{

	private MozillaDomBrowserGuiModel _model = (MozillaDomBrowserGuiModel) DefaultModelFactory.getInstance().resolveModel(
		MozillaDomBrowserGuiModel.MOZDOM_MODEL);

	private nsIRequest _curRequest;

	public MozillaDomBrowserControl (Composite parent, IWorkbenchPart enclosingPart) {
		super(parent, enclosingPart);
	}

	protected Composite createBrowser (Composite parent) throws Exception {
		final Browser browser = new Browser(parent, SWT.MOZILLA);
		final nsIWebBrowser webBrowser = (nsIWebBrowser) browser.getWebBrowser();
		// cannot use this as ProgressListener since ATF Mozilla browser 
		// does not account for 2nd STATE_STOP msg with STATE_IS_WINDOW 
		browser.addProgressListener(this);
		// causing JVM crash!!
		//webBrowser.addWebBrowserListener(this, nsIWebProgressListener.NS_IWEBPROGRESSLISTENER_IID);
		// load and sync history of web browser with nav bar
		final nsIWebNavigation navigation = (nsIWebNavigation) webBrowser.queryInterface(nsIWebNavigation.NS_IWEBNAVIGATION_IID);
		//final nsISHistory sessionHistory = createSessionHistory();
		//sessionHistory.addSHistoryListener(this);
		
		//navigation.setSessionHistory(sessionHistory);
		browser.addCloseWindowListener(new CloseWindowListener() {
			public void close (WindowEvent event) {
				IWorkbenchPage page = enclosingPart.getSite().getPage();
				if (enclosingPart instanceof IEditorPart && page.isPartVisible(enclosingPart)) {
					page.closeEditor((IEditorPart) enclosingPart, false);
					//sessionHistory.removeSHistoryListener(MozillaDomBrowserControl.this);
					//webBrowser.removeWebBrowserListener(MozillaDomBrowserControl.this, nsIWebProgressListener.NS_IWEBPROGRESSLISTENER_IID);
					browser.removeProgressListener(MozillaDomBrowserControl.this);
				}
			}
		});
		return browser;
	}

	public Object getDocument () {
		nsIWebBrowser webBrowser = (nsIWebBrowser) ((Browser) browser).getWebBrowser();
		Object docRoot = null;
		if (webBrowser != null) {
			docRoot = webBrowser.getContentDOMWindow().getDocument().getDocumentElement();
		}
		return docRoot;
	}

	protected nsISHistory createSessionHistory () {
		Mozilla moz = Mozilla.getInstance();
		String[] navBarHistory = navBar.getHistoryItems();
		nsIComponentManager compManager = moz.getComponentManager();
		nsIIOService ioService = (nsIIOService) moz.getServiceManager().getServiceByContractID(
			"@mozilla.org/network/io-service;1", nsIIOService.NS_IIOSERVICE_IID);
		nsISHistoryInternal sessionHistory = (nsISHistoryInternal) compManager.createInstanceByContractID(
			"@mozilla.org/browser/shistory;1", null,
			nsISHistoryInternal.NS_ISHISTORYINTERNAL_IID);
		for (int h = 0; h < navBarHistory.length; ++h) {
			nsISHEntry entry = (nsISHEntry) compManager.createInstanceByContractID(
				"@mozilla.org/browser/history-entry;1", null,
				nsISHEntry.NS_ISHENTRY_IID);
			try {
				entry.setURI(ioService.newURI(navBarHistory[h], null, null));
				sessionHistory.addEntry(entry, true);
			}catch (XPCOMException e) {
				continue;
			}
		}
		return (nsISHistory) sessionHistory.queryInterface(nsISHistory.NS_ISHISTORY_IID);
	}

	protected void setUrl (String url) {
		((Browser) browser).setUrl(url);
	}

	protected String getResourceName (String url) {
		String name = "<unknown resource>";
		try {
			url = url.replaceAll(" ", "%20");
			if (url.startsWith("www")) {
				url = "http://" + url;
			}

			URL temp = new URL(url);
			if (temp.getProtocol().equals("file")) {
				name = temp.getPath();
			}else if (temp.getProtocol().equals("http")) {
				String urlPath = temp.getPath();
				String path = urlPath == null || urlPath.length() == 0 ? "" : urlPath;
				name = temp.getHost() + "/" + path;
				((MozillaDomBrowserEditor) enclosingPart).setResource(null);
			}
		} catch (MalformedURLException e) {
			MozillaValidationUIPlugin.getDefault().logException("Invalid URL: " + url, e);
		}
		
		return name;
	}
	
	protected nsIDOMEventListener domValListener = new nsIDOMEventListener() {
		public void handleEvent (nsIDOMEvent event) {
			if (event.getType().equals("DOMNodeInserted")) {
				nsIDOMHTMLElement targetElement = (nsIDOMHTMLElement) event.getTarget().queryInterface(nsIDOMHTMLElement.NS_IDOMHTMLELEMENT_IID);
				// System.err.println("Inserted node:" + targetElement.getId());
				scheduleValidationJob(targetElement, false);
			}else if (event.getType().equals("DOMAttrModified")) {
				nsIDOMMutationEvent mutEvent = (nsIDOMMutationEvent) event.queryInterface(nsIDOMMutationEvent.NS_IDOMMUTATIONEVENT_IID);
				if (mutEvent.getAttrName().equals("style")
						&& mutEvent.getNewValue() != null &&mutEvent.getNewValue().indexOf("visibility:visible") >= 0) {
					nsIDOMHTMLElement targetElement = (nsIDOMHTMLElement) event.getTarget().queryInterface(
						nsIDOMHTMLElement.NS_IDOMHTMLELEMENT_IID);
					// System.err.println("Attr name: " + mutEvent.getAttrName() + " -- " + mutEvent.getPrevValue() + " -> " + mutEvent.getNewValue());
					scheduleValidationJob(targetElement, false);
				}
			}else {
				// System.err.println("Event type:"+event.getType());
			}
		}

		public nsISupports queryInterface (String iid) {
			return ((nsIWebBrowser) ((Browser) browser).getWebBrowser()).queryInterface(iid);
		}
	};

	protected void scheduleValidationJob (Object valTarget, boolean docLoaded) {
		String url = ((Browser) browser).getUrl();
		ValidationJob job = new MozillaValidationJob(url);
		if (autoValidating) {
			if (!docLoaded) {
				// same page so assume event-triggered:
				// need to transform the DOM node to particular HTML element type
				nsIDOMHTMLElement target = (nsIDOMHTMLElement) ((nsIDOMElement) valTarget).queryInterface(nsIDOMHTMLElement.NS_IDOMHTMLELEMENT_IID);
				valTarget = transformValidationTarget(target);
			}
			job.setProperty(ValidationJob.NEW_ACTION_QNAME, Boolean.valueOf(docLoaded));
			job.setProperty(ValidationJob.VALIDATION_TARGET_QNAME, valTarget);
			job.setResourceName(getResourceName(url));
			job.schedule();
		}
	}

	protected nsIDOMHTMLElement transformValidationTarget (nsIDOMHTMLElement target) {
		nsIDOMHTMLElement newTarget = null;
		String iid = _model.getIIDForTagName(target.getTagName());
		if (iid != null) {
			try {
				newTarget = (nsIDOMHTMLElement) target.queryInterface(iid);
			}catch (XPCOMException e) {
				LoggingUtil.println(IReporter.SYSTEM_NONFATAL,
					"Could not transform target with tagName: " + target.getTagName(), e);
			}
		}
		return newTarget;
	}

	public void completed (ProgressEvent event) {
		// will be removed when nsIwebProgress is working
		Exception e = new Exception();
		StackTraceElement[] stack = e.getStackTrace();
		
		boolean stop_window = stack[1].getMethodName().equals("OnStateChange") && stack[4].getClassName().equals(OS.class.getName());
		
		if (stop_window) {
			doDocumentCompleted();
		}
	}

	protected void doDocumentCompleted () {
		nsIWebBrowser webBrowser = (nsIWebBrowser) ((Browser) browser).getWebBrowser();
		
		nsIDOMDocument root = webBrowser.getContentDOMWindow().getDocument();
		nsIDOMEventTarget target = (nsIDOMEventTarget) root.queryInterface(nsIDOMEventTarget.NS_IDOMEVENTTARGET_IID);
		target.addEventListener("DOMActivate", domValListener, false);
		target.addEventListener("DOMAttrModified", domValListener, false);
		target.addEventListener("DOMNodeInserted", domValListener, false);
		
		nsIDOMElement rootElem = webBrowser.getContentDOMWindow().getDocument().getDocumentElement();
		nsIDOMHTMLElement topElement = null;
		String tagName = rootElem.getTagName();
		String iid = _model.getIIDForTagName(tagName);
		if (iid != null) {
			try {
				topElement = (nsIDOMHTMLElement) rootElem.queryInterface(iid);
			}catch (XPCOMException e) {
				LoggingUtil.println(IReporter.SYSTEM_NONFATAL, e);
			}
		}

		scheduleValidationJob(topElement, true);
	}

	// nsIWebProgressListener methods
	public void onStateChange (nsIWebProgress webProgress, nsIRequest request,
								long flags, long status) {
		if ((flags & nsIWebProgressListener.STATE_IS_DOCUMENT) != 0) {
			if ((flags & nsIWebProgressListener.STATE_START) != 0) {
				_curRequest = request;
			}else if ((flags & nsIWebProgressListener.STATE_STOP) != 0) {
				// ignore the STATE_STOP for document windows
				if ((flags & nsIWebProgressListener.STATE_IS_WINDOW) == 0
						&& _curRequest.getName().equals(request.getName())) {
					doDocumentCompleted();
					_curRequest = null;
				}
			}
		}
	}

	public void onProgressChange (nsIWebProgress webProgress,
									nsIRequest request, int curSelfProgress,
									int maxSelfProgress, int curTotalProgress,
									int maxTotalProgress) {
	}

	public void onLocationChange (nsIWebProgress webProgress,
									nsIRequest request, nsIURI location) {
	}

	public void onStatusChange (nsIWebProgress webProgress, nsIRequest request,
								long status, String message) {
	}

	public void onSecurityChange (nsIWebProgress webProgress,
									nsIRequest request, long state) {
	}

	// nsISHistoryListener methods
	public void onHistoryNewEntry (nsIURI uri) {
		navBar.updateHistory(uri.getSpec());
	}

	public boolean onHistoryGoBack (nsIURI uri) {
		navBar.updateLocation(uri.getSpec());
		return true;
	}

	public boolean onHistoryGoForward (nsIURI uri) {
		navBar.updateLocation(uri.getSpec());
		return true;
	}

	public boolean onHistoryReload (nsIURI uri, long arg) {
		return true;
	}

	public boolean onHistoryGotoIndex (int index, nsIURI uri) {
		navBar.updateLocation(uri.getSpec());
		return true;
	}

	public boolean onHistoryPurge (int arg) {
		return true;
	}

	public nsISupports getInterface (String riid) {
		return riid.equals(nsIDOMWindow.NS_IDOMWINDOW_IID)
			? ((nsIWebBrowser) ((Browser) browser).getWebBrowser()).getContentDOMWindow()
			: queryInterface(riid);
	}

	public nsISupports queryInterface (String iid) {
		nsIWebBrowser wb = (nsIWebBrowser) ((Browser) browser).getWebBrowser();
		return wb != null ? wb.queryInterface(iid) : null;
	}
}
