/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.webelo.ui.browser;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.IFileEditorInput;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.part.EditorPart;

public class MozillaDomBrowserEditor extends EditorPart
{

	protected BrowserControl browserCtrl;
	protected URL url;
	protected IResource resource;

	public MozillaDomBrowserEditor () {
		super();
	}

	public URL getUrl() {
		return url;
	}

	public void setUrl(URL url) {
		this.url = url;
	}

	public IResource getResource() {
		return resource;
	}

	public void setResource(IResource resource) {
		this.resource = resource;
	}

	public void doSave (IProgressMonitor monitor) {
	}

	public void doSaveAs () {
	}

	public void init (IEditorSite site, IEditorInput input)
		throws PartInitException {
		IResource resource = null;
		URL url = null;
		if (input instanceof MozillaDomBrowserEditorInput) {
			try {
				url = new URL(((MozillaDomBrowserEditorInput) input).getUrl());
				setSite(site);
				setInput(input);
			} catch (MalformedURLException e) {
				throw new PartInitException("Error opening ACTF Mozilla validation browser: invalid url");
			}
		} else if (input instanceof IFileEditorInput) {
			try {
				IFileEditorInput fileInput = (IFileEditorInput) input;
				resource = fileInput.getFile();
				url = resource.getRawLocation().toFile().toURL();
				setSite(site);
				setInput(new MozillaDomBrowserEditorInput(fileInput));
			} catch (Exception e) {
				throw new PartInitException("Error opening ACTF Mozilla validation browser");
			}
		} else {
			throw new PartInitException("Unknown input type to ACTF Mozilla validation browser");
		}

		setUrl(url);
		setResource(resource);
	}

	public boolean isDirty () {
		return false;
	}

	public boolean isSaveAsAllowed () {
		return false;
	}

	public void createPartControl (Composite parent) {
		Composite main = new Composite(parent, SWT.NONE);
		main.setLayout(new FillLayout());
		browserCtrl = new MozillaDomBrowserControl(main, this);
		browserCtrl.setLocation(((MozillaDomBrowserEditorInput) getEditorInput()).getUrl());
	}

	public void setFocus () {
		browserCtrl.getBrowser().setFocus();
	}

}
