/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 


package org.eclipse.actf.webelo.ui.browser;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.actf.validation.ui.jobs.ValidationJob;
import org.eclipse.actf.webelo.ui.MozillaValidationConstants;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.ide.IDE;

public class MozillaValidationJob extends ValidationJob
{

	public static final String WEB_VALIDATION_JOB_NAME = "Web Validation";
	
	private URL url;
	
	public MozillaValidationJob (URL url) {
		super(WEB_VALIDATION_JOB_NAME);
		this.url = url;
	}
	
	public MozillaValidationJob (String url) {
		super(WEB_VALIDATION_JOB_NAME);
		try {
			this.url = new URL(url);
		} catch (MalformedURLException e) {
			throw new IllegalArgumentException("Malformed URL: " + url);
		}
	}
	
	protected void preValidation () throws Exception {
		MozillaDomBrowserEditorInput editorInput = new MozillaDomBrowserEditorInput(url.toExternalForm());
		IDE.openEditor(getActivePage(), editorInput, MozillaValidationConstants.ACTF_MOZILLA_BROWSER_EDITOR_ID);
	}
	
	protected IWorkbenchPage getActivePage () {
		IWorkbenchPage page = null;
		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
		if (window != null) {
			page = window.getActivePage();
		}
		return page;
	}

	public void initialize(Object obj) throws Exception {
	}

	protected void reset() throws Exception {
		configureReportInstance();
	}
		
}
