/*******************************************************************************
* Copyright (c) 2004, 2008 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  IBM Corporation - initial API and implementation
*******************************************************************************/ 

package org.eclipse.actf.webelo.ui.dialogs;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.actf.validation.ui.GuiUtils;
import org.eclipse.actf.webelo.ui.MozillaValidationConstants;
import org.eclipse.actf.webelo.ui.browser.MozillaDomBrowserEditorInput;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.ide.IDE;

public class OpenWebBrowserDialog  extends Dialog{

	public static final String DIALOG_TITLE = "Open web browser with accessibility validation";
	public static final String ID = "org.eclipse.actf.validation.ui.dialogs.OpenWebBrowserDialog";

	public Text pathText = null;
	public OpenWebBrowserDialog(Shell parentShell) {
		super(parentShell);
	}

	protected void configureShell(Shell shell) {
		super.configureShell(shell);
		shell.setText(DIALOG_TITLE);
	}

	protected Control createDialogArea(Composite parent) {
		initializeDialogUnits(parent);
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayoutData(new GridData(GridData.FILL));
		GridLayout layout = new GridLayout();
		layout.numColumns = 4;
		composite.setLayout(layout);

		// Row 1 - group containing: radio button group for
		// either URL or Local file

		Group locGroup = new Group(composite, SWT.SHADOW_ETCHED_IN);
		locGroup.setLayout(new RowLayout(SWT.HORIZONTAL));
		locGroup.setText("HTML Location");
		GridData data = new GridData(GridData.FILL_BOTH);
		data.horizontalSpan =4; 
		locGroup.setLayoutData(data);
		Button locButton = new Button(locGroup, SWT.RADIO);
		locButton.setText("Local file system");
		locButton.setToolTipText("Choose this to select a file local file system");
	
		Button urlButton = new Button(locGroup, SWT.RADIO);
		urlButton.setText("URL");
		urlButton.setToolTipText("Choose this for a webpage");
	
		//Row2 - local file group
		final Label pathLabel = new Label(composite, SWT.LEFT);
		pathLabel.setText("Select Html File");
		GridData gd2 = new GridData(GridData.FILL_HORIZONTAL);
		gd2.horizontalSpan = 4;
		pathLabel.setLayoutData(gd2);
		pathText = new Text(composite, SWT.SINGLE);
		GridData gd3 = new GridData(GridData.FILL_HORIZONTAL);
		gd3.horizontalSpan = 3;
		gd3.widthHint = 300;
		pathText.setLayoutData(gd3);
		pathText.setToolTipText("Use the Browse button to select a valid html file");
		pathText.addModifyListener(new ModifyListener() {

			public void modifyText(ModifyEvent e) {
				if (pathText != null) {
					String text = pathText.getText();
					if(text!=null && text.trim().length()>0
							&& !text.equals("file:/") 
							&& !text.equals("http://")){
						getButton(OK).setEnabled(true);
					}
					else{
						getButton(OK).setEnabled(false);
					}
					
				}
			}

		});
		final Button sourceButton = new Button(composite, SWT.PUSH);
		GuiUtils.configureControl(sourceButton, "File",
				"Choose a html file to open", "Browse...");
		SelectionListener sourceListener = new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				File sourceFile = getHtmlFile();
				if(sourceFile!=null)
				 pathText.setText("file:/"+sourceFile.getPath());
			}
		};
		sourceButton.addSelectionListener(sourceListener);
	
		SelectionListener localButtonListener = new SelectionAdapter() {

			public void widgetSelected(SelectionEvent e) {
				pathLabel.setText("Select Html File");
				sourceButton.setVisible(true);
				pathText.setText("");				
				pathText.setToolTipText("Use the Browse button to select a valid html file");

			}
		};

		locButton.addSelectionListener(localButtonListener);

	
		SelectionListener remoteButtonListener = new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				pathLabel.setText("Enter URL:");
				sourceButton.setVisible(false);
				pathText.setText("http://");
				pathText.setToolTipText("Enter the web address in the format 'http://www.ibm.com'");
			}
		};
		urlButton.addSelectionListener(remoteButtonListener);

		return composite;
	}

	protected void initializeBounds() {
		getButton(OK).setEnabled(false);
		super.initializeBounds();
	}
	private File getHtmlFile() {
		FileDialog fd = new FileDialog(getShell(), SWT.OPEN);
		fd.setFilterExtensions(new String[] { "*.*htm*"});
		fd.setFilterNames(new String[] { "Html Files" });
		File file = null;
		String path = fd.open();
		if (path != null && path.length() > 0) {
			file = new File(path);
		}
		return file;
	}

	protected void okPressed() {

		IWorkbenchPage page = null;
		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
		if (window != null) {
			page = window.getActivePage();
		}

		try {
			URL url = new URL(pathText.getText().replaceAll(" ", "%20"));
			MozillaDomBrowserEditorInput editorInput = new MozillaDomBrowserEditorInput(url.toExternalForm());
			IDE.openEditor(page, editorInput, MozillaValidationConstants.ACTF_MOZILLA_BROWSER_EDITOR_ID);
		} catch (PartInitException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (MalformedURLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		super.okPressed();

	}
}
