/*******************************************************************************
* Copyright (c) 2004, 2007 IBM Corporation.
* All rights reserved. This program and the accompanying materials
* are made available under the terms of the Eclipse Public License v1.0
* which accompanies this distribution, and is available at
* http://www.eclipse.org/legal/epl-v10.html
*
* Contributors:
*  Mike Squillace - initial API and implementation
*******************************************************************************/ 


package org.eclipse.actf.webelo.wst.ui.mozdom;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.actf.webelo.ui.MozillaValidationUIPlugin;
import org.eclipse.actf.webelo.ui.browser.MozillaValidationJob;
import org.eclipse.actf.webelo.wst.ui.ILaunchConfigurationConstants;
import org.eclipse.actf.webelo.wst.ui.WstValidationUtils;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.debug.core.ILaunch;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.model.LaunchConfigurationDelegate;
import org.eclipse.wst.server.core.IModule;
import org.eclipse.wst.server.core.IServer;
import org.eclipse.wst.server.core.ServerPort;

public class MozValidationLaunchConfigurationDelegate extends LaunchConfigurationDelegate
{

	private IServer server;
	
	public void launch(ILaunchConfiguration configuration, String mode,
	                   ILaunch launch, IProgressMonitor monitor) throws CoreException {
		String appPath = configuration.getAttribute(ILaunchConfigurationConstants.ATTR_APP_PATH, (String)null);
		String appName = configuration.getAttribute(ILaunchConfigurationConstants.ATTR_PROCESS_TYPE, (String)null);
		boolean isUrl = configuration.getAttribute(ILaunchConfigurationConstants.ATTR_IS_URL, false);
		
		if(isUrl) {
			launchApp(mode, appName, appPath, null, isUrl);
		} else {
			String projectName = configuration.getAttribute(ILaunchConfigurationConstants.ATTR_PROJECT, (String)null);
			String moduleName = configuration.getAttribute(ILaunchConfigurationConstants.ATTR_WEB_MODULE, (String)null);
			IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(projectName);
			launchServerAndApp(project, appName, moduleName, appPath, mode, monitor);
		}
	}
	
	private void launchServerAndApp (IProject project, String appName, String moduleName,
	                                     String appPath, String mode, IProgressMonitor monitor) throws CoreException {
		server = WstValidationUtils.getServer(project, moduleName, mode, monitor);
		if(server != null) {
			launchApp(mode, appName, appPath, moduleName, false);
		} else {
			throw new CoreException(new Status(
				IStatus.ERROR, MozillaValidationUIPlugin.UI_PLUGIN_ID, IStatus.OK,
				"Could not launch server for ACTF Mozilla validation", null
			));
		}
	}
	
	private void launchApp (String mode, String appName, String appPath,
	                       String moduleName, boolean isUrl) throws CoreException {   
		Job job = null;
		if(isUrl) {
			URL url = null;
			try {
				url = new URL(appPath);
			} catch(MalformedURLException e) {
				throw new CoreException(new Status(
					IStatus.ERROR, MozillaValidationUIPlugin.UI_PLUGIN_ID,
					IStatus.OK, "Unable to parse URL:" + appPath, e
				));
			}
			job = new MozillaValidationJob(url);
			job.schedule();
		} else {
			URL url = getURL(moduleName, appPath);
			IModule module = null;
			for(IModule mod : server.getModules()) {
				if(mod.getName().equals(moduleName)) {
					module = mod;
					break;
				}
			}

			if (module != null) {
				job = new MozillaValidationJob(url);
				WstValidationUtils.startServer(server, module, mode, job);
			} else {
				throw new CoreException(new Status(
					IStatus.ERROR, MozillaValidationUIPlugin.UI_PLUGIN_ID, IStatus.OK,
					"The selected file can not be launched because the project has not been added to a server.", null
				));
			}
		}
	}
		
	private URL getURL(String module, String appPath) throws CoreException {
		URL url = null;
		int port = 8080;
		
		if(server != null) {
				for(ServerPort serverPort : server.getServerPorts(null)) {
					if(serverPort.getProtocol().equals("HTTP")) {
						port = serverPort.getPort();
						break;
					}
				try {
					url = new URL("http", "localhost", port, "/" + module + "/" + appPath);
				} catch(MalformedURLException e) {
					throw new CoreException(new Status(
						IStatus.ERROR, MozillaValidationUIPlugin.UI_PLUGIN_ID, IStatus.OK,
						"Unable to parse URL", e
					));
				}
			}
		}
		
		return url;
	}
	
}
