/*******************************************************************************
 * Copyright (c) 2006, 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/


package org.eclipse.actf.webelo.wst.ui.mozdom;

import java.io.File;
import java.net.MalformedURLException;

import org.eclipse.actf.webelo.wst.ui.ILaunchConfigurationConstants;
import org.eclipse.actf.webelo.wst.ui.WstValidationUtils;
import org.eclipse.actf.webelo.wst.ui.debug.WstValidationLaunchConfigurationTab;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.Path;
import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;

public class MozValidationLaunchConfigurationTab extends WstValidationLaunchConfigurationTab
{

	public MozValidationLaunchConfigurationTab(String mode) {
		super(mode);
	}

	public void performApply(ILaunchConfigurationWorkingCopy config) {
			String pathText = pathField.getText();
			
			if (isLocalFile) {
				try {
					pathText = new File(pathText).toURL().toExternalForm();
				} catch (MalformedURLException mfe) {
				}
			}
			if( isURL || isLocalFile) {
				config.setAttribute(ILaunchConfigurationConstants.ATTR_APP_PATH, pathText);
				config.setAttribute(ILaunchConfigurationConstants.ATTR_PROJECT, "");
				config.setAttribute(ILaunchConfigurationConstants.ATTR_IS_URL, true);
			} else {
				try {
					Path path = new Path(pathText);
					IFile file = ResourcesPlugin.getWorkspace().getRoot().getFile(path);
					String projectName = path.segment(0);
					IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(projectName);
					config.setAttribute(ILaunchConfigurationConstants.ATTR_PROJECT, projectName);
					config.setAttribute(ILaunchConfigurationConstants.ATTR_WEB_MODULE, project != null ? project.getName() : null);
					config.setAttribute( ILaunchConfigurationConstants.ATTR_APP_PATH, WstValidationUtils.getWebContentRelativePath(file));
					config.setAttribute(ILaunchConfigurationConstants.ATTR_IS_URL, false);
				} catch( Exception e ) {
				}
			}
			
			config.setAttribute( ILaunchConfigurationConstants.ATTR_PROCESS_TYPE,  getName());
			config.setAttribute(ILaunchConfigurationConstants.ATTR_FULL_PATH, pathField.getText());
	}
	
	public String getName() {
		return "Mozilla Validation";
	}

}
